*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica, Forthcoming
*******************************************************************************************
*******************************************************************************************

clear
set more off
cap ssc install mmerge

*******************************************************************************************
* Survey of English Housing, 1993/94-2007/08
*    For Appendix Table A.2
*******************************************************************************************

use "1994-2007\stata8\seh15.dta" , clear

* Keep only owners
keep if tenure4 == 1	

* Generate Leasehold Variable
gen     leasehold = 0 if lease == 1
replace leasehold = 1 if lease == 3
drop if leasehold == .

* Level of Clustering SE
egen group_cluster1 = group(accomhh1 survyear newlacode)

* Dependent variables
gen married          = (mshrp    == 1)
gen first_time_buyer = (ftbuyer2 == 1)
gen very_satisfied   = (has44    == 1)
gen has_mortgage     = (tenure1  == 2)
gen prev_ex_3y       = (hlong2 > 3) 

foreach d in "nrooms" "yrbult" {
	replace `d' = 999 if `d' < 0
	replace `d' = 999 if `d' == .
}

gen 	house = 0
replace house = 1 if accomhh == 1 | accomhh == 2 | accomhh == 3

***************************************************************************
* Figure out differences between leasehold and freehold owners
***************************************************************************
 
sum  agehrp                               [aweight = weight] if house == 1 & agehrp > 0  
reg  agehrp 				  i.leasehold [aweight = weight] if house == 1 & agehrp > 0
areg agehrp 				  i.leasehold [aweight = weight] if house == 1 & agehrp > 0, absorb(group_cluster1) cluster(group_cluster1)
areg agehrp i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1 & agehrp > 0, absorb(group_cluster1) cluster(group_cluster1)

sum  weekhrp							   [aweight = weight] if house == 1 & weekhrp > 0	
reg  weekhrp                   i.leasehold [aweight = weight] if house == 1 & weekhrp > 0
areg weekhrp 				   i.leasehold [aweight = weight] if house == 1 & weekhrp > 0, absorb(group_cluster1) cluster(group_cluster1)
areg weekhrp i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1 & weekhrp > 0, absorb(group_cluster1) cluster(group_cluster1)

sum  npers 						  		    [aweight = weight] if house == 1
reg  npers   					i.leasehold [aweight = weight] if house == 1
areg npers                      i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)
areg npers   i.yrbult  i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)

sum ndepch 						   		   [aweight = weight] if house == 1
reg ndepch   				   i.leasehold [aweight = weight] if house == 1
areg ndepch                    i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)
areg ndepch  i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)

sum married								   [aweight = weight] if house == 1
reg married   				   i.leasehold [aweight = weight] if house == 1
areg married 				   i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)
areg married i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)

sum first_time_buyer								[aweight = weight] if house == 1
reg first_time_buyer   					i.leasehold [aweight = weight] if house == 1
areg first_time_buyer 					i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)
areg first_time_buyer i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)

sum has_mortgage								[aweight = weight] if house == 1
reg has_mortgage   					i.leasehold [aweight = weight] if house == 1
areg has_mortgage 					i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1)  cluster(group_cluster1)
areg has_mortgage i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1)  cluster(group_cluster1)

sum very_satisfied								  [aweight = weight] if house == 1
reg very_satisfied   				  i.leasehold [aweight = weight] if house == 1
areg very_satisfied  				  i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)
areg very_satisfied i.yrbult i.nrooms i.leasehold [aweight = weight] if house == 1, absorb(group_cluster1) cluster(group_cluster1)

*******************************************************************************************
* English Housing Survey 2011-12
* - For Ground Rent and Service Charge numbers in paper and appendix
*******************************************************************************************
  
use "2011-2012\stata9\derived\interviewfs11.dta", clear

mmerge aacode using "2011-2012\stata9\interview\owner.dta" 
keep if _merge == 3
drop _merge
mmerge aacode using "2011-2012\stata9\derived\generalfs11.dta" 
keep if _merge == 3
drop _merge
mmerge aacode using "2011-2012\stata9\interview\attitudes.dta" 
keep if _merge == 3
drop _merge

*****************************************
* Is a house
*****************************************

gen 	house = 0
replace house = 1 if accomhh == 1 | accomhh == 2 | accomhh == 3

gen     leasehold = 0 if freeleas == 1
replace leasehold = 1 if freeleas == 2

*****************************************
* Data on Ground Rent and Service Charges
*****************************************

* Ground Rent
tab rygrdrnt if leasehold == 1 & (rygrdrnt == 1 | rygrdrnt == 2) & house == 1 [aweight = aagfh11]

replace rygrdwk = 0 if rygrdrnt == 2
replace rygrdwk = . if rygrdwk  == -9

* Weekly ground rents
sum     rygrdwk [aweight = aagfh11] if leasehold == 1 & house == 1, d

* Service Charges
gen pays_service_charge   = (rysvcchg == 1)

* How many people pay service charge
tabstat pays_service_charge [aweight = aagfh11] if leasehold == 1, by(house)
tabstat pays_service_charge [aweight = aagfh11] if leasehold == 1 & house == 1, by(region3x)

* What is the weekly service charge that is being paid
replace rysvwk = . if rysvwk == -9
sum     rysvwk  [aweight = aagfh11] if pays_service_charge == 1 & leasehold == 1 & house == 1, d
