*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica, Forthcoming
*******************************************************************************************
*******************************************************************************************

* ----------------------------------------------------------
* Code to reproduce Figure 1
* ----------------------------------------------------------

*****************
*** PRICE LEVELS
*****************

use gp_levels.dta, clear

local   temp    = rhpi_uk[1]
replace rhpi_uk = rhpi_uk/`temp'
replace rhpi_uk = log(rhpi_uk)

local   temp    = rhpi_sg[1]
replace rhpi_sg = rhpi_sg/`temp'
replace rhpi_sg = log(rhpi_sg)

* PANEL A
line rhpi_uk date_uk, lwidth(0.5) ytitle("Real House Price (log)") xtitle("") scheme(s1mono) ///
	   legend(off) xlabel(#12) xline(1971.5 1972.5 2002.5 2003.5, lwidth(3) lcolor(gs15))

* PANEL B
line rhpi_sg date_sg, lwidth(0.5) ytitle("Real House Price (log)") xtitle("") scheme(s1mono) ///
	   legend(off) xlabel(#8) xline(1980.5 1993.5 1994.5 1995.5 2007,lcolor(gs15) lwidth(3.5))
	   
**********************
*** PRICE RATIOS
**********************

use gp_figratios.dta, clear

gen pm_uk       = log(price_median)
egen temp     = mean(pm_uk)
replace pm_uk = pm_uk-temp
drop temp

gen pr_uk       = log(price_rent_uk)
egen temp     = mean(pr_uk)
replace pr_uk = pr_uk-temp
drop temp

gen pg_uk       = log(price_gdp_uk)
egen temp     = mean(pg_uk)
replace pg_uk = pg_uk-temp
drop temp

gen pc_uk       = log(price_cons_uk)
egen temp     = mean(pc_uk)
replace pc_uk = pc_uk-temp
drop temp

* PANEL C
twoway  (line pr_uk date_uk, lpattern(solid) lwidth(0.8) lcolor(black)) (line pg_uk date_uk, lwidth(0.5) lcolor(black) lpattern(dash)) (line pc_uk date_uk, lwidth(1) lcolor(black) lpattern(dot)) (line pm_uk date_uk, ), ytitle("Price ratios (logs)") xtitle("") scheme(s1mono) ///
	     legend(label(1 "Price to rent") label(2 "Price to per capita GDP") label(3 "Price to per capita consumption") label(4 "Price to median income")) xlabel(#12) xline(1971.5 1972.5 2002.5 2003.5, lwidth(3) lcolor(gs15))	   

gen pr_sg       = log(price_rent_sg)
egen temp     = mean(pr_sg)
replace pr_sg = pr_sg-temp
drop temp

gen pg_sg       = log(price_gdp_sg)
egen temp     = mean(pg_sg)
replace pg_sg = pg_sg-temp
drop temp

gen pc_sg       = log(price_cons_sg)
egen temp     = mean(pc_sg)
replace pc_sg = pc_sg-temp
drop temp

replace pr_sg = pr_sg+0.5

* PANEL D

twoway (line pr_sg date_sg, lpattern(solid) lwidth(0.8) lcolor(black)) (line pg_sg date_sg, lwidth(0.5) lcolor(black) lpattern(dash)) (line pc_sg date_sg, lwidth(1) lcolor(black) lpattern(dot)), ytitle("Price ratios (logs)") xtitle("") scheme(s1mono) ///
	   legend(label(1 "Price to rent") label(2 "Price to per capita GDP") label(3 "Price to per capita consumption") )  xlabel(#8) xline(1980.5 1993.5 1994.5 1995.5 2007,lcolor(gs15) lwidth(3.5) )

*********************	   
*** Newspapers data
*********************

use "gp_estimates.dta", clear
sort date
merge date using "ProQuest"

local temp=hpi_uk[1]
replace hpi_uk=hpi_uk-`temp'

local temp=london[1]
replace london=london-`temp'

local temp=pcl[1]
replace pcl=pcl-`temp'

* PANEL E
twoway (bar  UK_news date, yaxis(2) yscale(alt axis(2)) fintensity(20) barwidth(1)) ///
	   (line hpi_uk date, lpattern(solid) lwidth(0.5) lcolor(black) yscale(alt))  ///
	   (line london date, lpattern(solid) lwidth(0.5) lcolor(black) lpattern(dash)) ///
	   (line pcl date, lpattern(solid) lwidth(1.5) lcolor(black) lpattern(dot)), ///
	   ytitle("Real House Price Index (Log Scale)") xtitle("") ylabel(0(0.2)1.2, axis(1)) ylabel(0(100)500, axis(2)) xlabel(#18, angle(vertical)) ///
	   ytitle("Newspaper 'Bubble Index'", axis(2)) plotregion(lstyle(none)) scheme(s1mono) /// 
	   legend(order (2 3 4) label(1 "") label(2 "U.K.") label(3 "London") label(4 "PCL") cols(3) ring(0) position(10) region(lwidth(none))) 	   

use "gp_estimates.dta", clear
sort  date
merge date using "ProQuest"

local temp=hpi_sg[1]
replace hpi_sg=hpi_sg-`temp'


twoway (bar  SG_news date, yaxis(2) yscale(alt axis(2)) fintensity(20) barwidth(1)) ///
	   (line hpi_sg date, lpattern(solid) lwidth(0.5) lcolor(black) yscale(alt)),  ///
	   ytitle("Real House Price Index (Log Scale)") xtitle("") ylabel(0(100)300, axis(2)) xlabel(#18, angle(vertical)) ///
	   ytitle("Newspaper 'Bubble Index'", axis(2)) plotregion(lstyle(none)) scheme(s1mono) legend(off) 	   

