*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

*******************************************************************************************
* SINGAPORE DATA PROCESSING - PART 2
* Read in data from iProperty (proprietary)
*******************************************************************************************

clear
set more off
cap ssc install mmerge

set more off

use "Listings\iPropertySG-listings.dta", clear

drop if v102 == ""
compress

rename v1   listinid
rename v2   code
rename v3   listingtype
rename v4   progrtype
rename v5   ib
rename v6   phone_off
rename v7   name
rename v8   agent
rename v9   agentb
rename v10  cat
rename v11  date
rename v12  type
rename v13  mlsstatus
rename v14  own_type
rename v15  storey
rename v16  street
rename v17  estate
rename v18  block
rename v19  district 
rename v20  no
rename v21  unit
rename v22  postalcode
rename v23  fixtures
rename v24  fixtures2
rename v25  living
rename v26  dining
rename v27  bedroom
rename v28  kitchen
rename v29  asking
rename v30  psf
rename v31  sale
rename v32  partition
rename v33  furniture
rename v34  phone_sys
rename v35  loading
rename v36  lifts
rename v37  car_park
rename v38  cleiling
rename v39  expire
rename v40  selling
rename v41  land
rename v42  built_in
rename v43  tenure 
rename v44  age
rename v45  bedrooms
rename v46  bath
rename v47  attachbath
rename v48  guest
rename v49  utility
rename v50  avail
rename v51  top 
rename v52  maintain
rename v53  tax
rename v54  source
rename v55  facing
rename v56  appoint
rename v57  amentiy
rename v58  remarks
rename v59  facility
rename v60  family
rename v61  agentid
rename v62  maplat
rename v63  maplong
rename v64  youtubeid
rename v65  mainphoto
rename v66  laytype
rename v67  livingreno
rename v68  diningreno
rename v69  bedroomreno
rename v70  kitchenreno
rename v71  remtenure
rename v72  furnishingcode
rename v73  directionid
rename v74  occupiedcode
rename v75  airconcode
rename v76  attrcode 
rename v77  carparktype
rename v78  protype
rename v79  tenureid
rename v80  premiumlisting
rename v81  premiumstartdate
rename v82  premiumdate
rename v83  issale
rename v84  isrent
rename v85  rentalprice
rename v86  askingpsf
rename v87  rentalpsf
rename v88  askingprice
rename v89  status
rename v90  listingmanageid
rename v91  importedverified
rename v92  goviewurl
rename v93  sizemeasurecode
rename v94  isfeatured
rename v95  premiumlistingorder
rename v96  ispostedrefresh
rename v97  landareapsf
rename v98  level
rename v99  importrefno
rename v100 buildingname
rename v101 istransmit
rename v102 copyoflevel

*******************************************************************************************
* Data Processing
*******************************************************************************************

drop name agent cat agentb
drop ib phone_off
drop amentiy remarks facility
drop youtubeid mainphoto laytype
drop goviewurl ispostedrefresh
drop istransmit
drop copyoflevel
drop premiumlistingorder isfeatured importedverified listingmanageid
drop premium*
drop appoint
drop avail top
destring(family agentid bedrooms bath attachbath guest utility), replace force

* Indicator for data that didn't read in well
gen     d = length(furnish)
drop    if d > 10
replace street = substr(street,1,50)

drop estate partition phone_sys d asking buildingname

* Create a for-rent indicator (the iProperty data has for-rent and for-sale listings)
replace isrent = trim(isrent)
gen for_rent   = (isrent == "True")
drop issale isrent

* Convert monthly rental prices into annual
destring(askingprice rentalprice), replace force
gen     price = 12*rentalprice if for_rent == 1
replace price = askingprice    if for_rent == 0
drop if price == 0
drop askingprice rentalprice

* Date Variable
replace date = trim(date)
gen date_new = date(substr(date,1,10),"YMD")
drop date 

* Create property size indicator. For some it is reported in square-meters, so have to turn those into square feet
* to have a common unit of measurement.
destring(built_in), replace force
gen     size = built_in
replace size = size*10.76 if sizemeasurecode  == "M"
drop built_in

save "Listings\iPropertySG-listings.dta", replace
