*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

*******************************************************************************************
* SINGAPORE DATA PROCESSING - PART 5
* - Hedonic Regression Analysis
*******************************************************************************************

set more off
set matsize 11000

use "cleaned_data.dta", clear

**************************************************************************
* Draw Appendix Figure with Share of Property Transaction / Origination
* FIGURE A.6
**************************************************************************

preserve

keep if ll_remain3 == 0 | ll_remain3 == 6

gen freehold = (ll_remain3 == 0)

collapse (mean) freehold, by(contract_year new)

tsset new contract_year

twoway (tsline freehold if new == 0, lcolor(black)) (tsline freehold if new == 1, lpattern(dash)), yscale(range(0.7 1)) ytitle(Share of properties trading as freehold) ///
        ylabel(0.7(0.05)1) xtitle("") legend(label(1 "Existing Properties") label(2 "New Properties")  region(lstyle(none))) scheme(s1mono)

graph export "TS_Share_FH_SG.pdf"
	   
restore

*********************************************************************
* Figure, Discount of Extremely-Long Leaseholds By Year
* FIGURE II, Panel B
*********************************************************************

forval y = 1995(1)2013 {
	gen     lly_`y' = 0
	replace lly_`y' = 1 if ll_remain3 == 6 & contract_year == `y'
}

areg log_price i.age i.size_group2 i.prop_type i.total_units_group llr2 llr3 llr4 llr5 llr6 lly_*, absorb(time_loc_type3) cluster(round_postal3)

preserve

parmest, norestore

keep if strpos(parm,"lly_") != 0
gen ll_year = substr(parm,5,4)
destring(ll_year), replace force

graph twoway (bar estimate ll_year, barwidth(0.7)) (rcap max95 min95 ll_year, lcolor(black) lwidth(thick)), ///
			 name(fig_ts_disc, replace) xtitle("Year") ///
			 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
			 scheme(s1mono) legend(off)  yscale(range(-0.03 0.03)) ylabel(#7) xlabel(#18, angle(vertical)) 
						 
			 graph export "Bubble_SG.pdf"
restore

*********************************************************************
* Estimates in regression Tables II and III
*********************************************************************

fvset base 1 age size_group2 prop_type total_units_group
 
* COL 5 - TABLE II
areg log_price i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7, absorb(time_loc_type1)  cluster(round_postal3) 

* COL 6 - TABLE II
areg log_price i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7, absorb(time_loc_type2)  cluster(round_postal3) 

* COL 7 - TABLE II
areg log_price i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7, absorb(time_loc_type3)  cluster(round_postal3) 

* COL 8 - TABLE II
areg log_price_w05 i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7, absorb(time_loc_type1) cluster(round_postal3) 

* COL 2 - TABLE III - PANEL A
areg log_price i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7 if year == 1995 | year == 1996 | year == 2007, absorb(time_loc_type3)  cluster(round_postal3) 

* COL 5 - TABLE III - PANEL A
areg log_price i.age i.size_group2 i.total_units_group llr2 llr3 llr4 llr5 llr6 llr7 if planningregion=="Central Region", absorb(time_loc_type3) cluster(round_postal3) 

******************************************************
* OBSERVABLES RESIDUALS - FIGURE A.4
******************************************************
	   	   
egen     FE_Graph = group(typeofarea round_postal3 prop_type)

areg log_price, absorb(FE_Graph)
predict resid_price, r

twoway (kdensity resid_price if resid_price < 1 & resid_price > -1 & ll_remain3 == 6, bwidth(0.01) lpattern(solid)) ///
	   (kdensity resid_price if resid_price < 1 & resid_price > -1 & ll_remain3 == 0, bwidth(0.01) lpattern(dash)), ///
	   legend(lab(1 "700+ Year Leasehold") lab(2 "Freehold")  col(4) region(lstyle(none))) ///
	   scheme(s1mono) xtitle(log(Price) - Residual) ytitle("") scale(1.4)
	
graph export "SG_Resid_Price.pdf"
	   
areg areasqm, absorb(FE_Graph)
predict resid_area, r

twoway (kdensity resid_area if resid_area < 100 & resid_area > -100 & ll_remain3 == 6, bwidth(8) lpattern(solid)) ///
	   (kdensity resid_area if resid_area < 100 & resid_area > -100 & ll_remain3 == 0, bwidth(8) lpattern(dash)), ///
	   legend(lab(1 "700+ Year Leasehold") lab(2 "Freehold")  col(4) region(lstyle(none))) ///
	   scheme(s1mono) xtitle(Property Size - Residual) ytitle("") scale(1.4)
       
graph export "SG_Resid_Size.pdf"
	   
areg age, absorb(FE_Graph)
predict resid_age, r

twoway (kdensity resid_age if resid_age < 15 & resid_age > -15 & ll_remain3 == 6, bwidth(1.5)  lpattern(solid)) ///
	   (kdensity resid_age if resid_age < 15 & resid_age > -15 & ll_remain3 == 0, bwidth(1.5)  lpattern(dash)),  ///
	   legend(lab(1 "700+ Year Leasehold") lab(2 "Freehold")  col(4) region(lstyle(none))) ///
	   scheme(s1mono) xtitle(Property Age - Residual) ytitle("") scale(1.4)	   
	   	
graph export "SG_Resid_Age.pdf"
