*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

****************************************************************************************************************
* READ IN THE UK TRANSACTION DATA DOWNLOADED FROM THE LAND REGISTRY WEBSITE
* - This file reads in the "Price Paid" Dataset from the UK Land Registry
* - Download this data from https://www.gov.uk/government/statistical-data-sets/price-paid-data-downloads
****************************************************************************************************************

clear
set more off

************************************************************************
* Read in data, name variables, create date variables
************************************************************************

import delimited "Data\pp-complete.csv", clear 

duplicates drop

rename v1  unique_id
rename v2  price
rename v3  date
rename v4  postcode
rename v5  prop_type
rename v6  old_new
rename v7  duration
rename v8  street_number
rename v9  flat_number
rename v10 street
rename v11 locality
rename v12 district
rename v13 town
rename v14 county
rename v15 record_status

gen     length_date = length(date)
replace date = substr(date,1,length(date)-5) if length_date == 16
replace date = substr(date,1,length(date)-8) if length_date == 19
replace date = subinstr(date,"/","-",.)

gen     date_trans = date(date,"DMY")
replace date_trans = date(date,"YMD") if date_trans == .
replace date       = substr(date,1,length(date)-2) + "20" + substr(date,length(date)-1,.) if date_trans == .
replace date_trans = date(date,"DMY") if date_trans == .
format  date_trans %td

drop length_date date

***************************************************************************
* Now do some data-cleaning
***************************************************************************

replace flat_number = subinstr(flat_number,"FLAT","",.)
replace flat_number = subinstr(flat_number,"APARTMENT","",.)
replace flat_number = trim(flat_number)

compress

save "Data\TransactionsLRLong.dta", replace
