*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

************************************************************************
* Regressions that produce outputs along a number of cuts of the data 
* by regions that looked "bubbly" for TABLE III
************************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

*************************************************
* Merge Postcode-Level Data (See Data Appendix)
*************************************************

sort postcode 
cap noisily merge postcode using "Cross-Section Data\PriceIncome.dta"
keep if _merge == 3 | _merge == 1
cap drop _merge

sort  postcode
cap noisily merge postcode using "Cross-Section Data\HousingStockGrowth.dta"			   
keep if _merge == 3 | _merge == 1
cap drop _merge

* Calculate growth of Price/Income Ratio
gen pi_growth = price_income_ratio_07 - price_income_ratio_04

* Find averages of measures by LSOA-Year
bysort lsoa year: egen mean_pi04 = mean(price_income_ratio_04)
xtile dd_pi04=mean_pi04, n(5)

bysort lsoa year: egen mean_pig = mean(pi_growth)
xtile dd_pig=mean_pig, n(5)

bysort lsoa year: egen mean_tom = mean(tom)
xtile dd_tom=mean_tom, n(5) 

gen qu = quarter(date_trans)

* GET POSTCODE REGION
gen first_digit  = substr(postcode,1,1)
gen second_digit = substr(postcode,2,1)
destring(second_digit), replace force

cap drop postcode_district     
gen postcode_district     = first_digit if second_digit != .
replace postcode_district = substr(postcode,1,2) if postcode_district == ""

gen    region = postcode_district	
bysort region: egen mean_lhs = mean(yg_house5)

* Generate bubble indicator based on the Time-Series Tests in Matlab
gen     isbubbly=0
replace isbubbly=1 if  (region=="AL" & year==1999 & qu==2) | (region=="AL" & year==1999 & qu==3) | (region=="AL" & year==1999 & qu==4) | (region=="AL" & year==2000 & qu==1) | (region=="AL" & year==2000 & qu==2) | (region=="AL" & year==2000 & qu==3) | (region=="AL" & year==2002 & qu==2) | (region=="AL" & year==2002 & qu==3) | (region=="AL" & year==2002 & qu==4) 
replace isbubbly=1 if  (region=="B"  & year==1999 & qu==2) | (region=="B"  & year==1999 & qu==3) | (region=="B"  & year==1999 & qu==4) | (region=="B"  & year==2000 & qu==1) | (region=="B"  & year==2000 & qu==2) | (region=="B"  & year==2000 & qu==3) | (region=="B" & year==2000 & qu==4) | (region=="B" & year==2001 & qu==1) | (region=="B" & year==2001 & qu==2) | (region=="B" & year==2001 & qu==3) | (region=="B" & year==2001 & qu==4) | (region=="B" & year==2002 & qu==1) | (region=="B" & year==2002 & qu==2) | (region=="B" & year==2002 & qu==3) | (region=="B" & year==2002 & qu==4) | (region=="B" & year==2003 & qu==1) | (region=="B" & year==2003 & qu==2) | (region=="B" & year==2003 & qu==3) | (region=="B" & year==2003 & qu==4) | (region=="B" & year==2004 & qu==1) | (region=="B" & year==2004 & qu==2) | (region=="B" & year==2004 & qu==3) | (region=="B" & year==2004 & qu==4) | (region=="B" & year==2005 & qu==1) | (region=="B" & year==2005 & qu==2) | (region=="B" & year==2005 & qu==3) 
replace isbubbly=1 if  (region=="BA" & year==1999 & qu==1) | (region=="BA" & year==1999 & qu==2) | (region=="BA" & year==1999 & qu==3) | (region=="BA" & year==1999 & qu==4) | (region=="BA" & year==2000 & qu==1) | (region=="BA" & year==2000 & qu==2) | (region=="BA" & year==2000 & qu==3) | (region=="BA" & year==2000 & qu==4) | (region=="BA" & year==2001 & qu==1) | (region=="BA" & year==2001 & qu==2) | (region=="BA" & year==2001 & qu==3) | (region=="BA" & year==2001 & qu==4) | (region=="BA" & year==2002 & qu==1) | (region=="BA" & year==2002 & qu==2) | (region=="BA" & year==2002 & qu==3) | (region=="BA" & year==2002 & qu==4) | (region=="BA" & year==2003 & qu==1) | (region=="BA" & year==2003 & qu==2) | (region=="BA" & year==2003 & qu==3) | (region=="BA" & year==2003 & qu==4) | (region=="BA" & year==2004 & qu==1) | (region=="BA" & year==2004 & qu==2) | (region=="BA" & year==2004 & qu==3) | (region=="BA" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="BB" & year==2001 & qu==2) | (region=="BB" & year==2001 & qu==3) | (region=="BB" & year==2001 & qu==4) | (region=="BB" & year==2002 & qu==1) | (region=="BB" & year==2002 & qu==2) | (region=="BB" & year==2002 & qu==3) | (region=="BB" & year==2002 & qu==4) | (region=="BB" & year==2003 & qu==1) | (region=="BB" & year==2003 & qu==2) | (region=="BB" & year==2003 & qu==3) | (region=="BB" & year==2003 & qu==4) | (region=="BB" & year==2004 & qu==1) | (region=="BB" & year==2004 & qu==2) | (region=="BB" & year==2004 & qu==3) | (region=="BB" & year==2004 & qu==4) | (region=="BB" & year==2005 & qu==1) | (region=="BB" & year==2005 & qu==2) | (region=="BB" & year==2005 & qu==3) | (region=="BB" & year==2005 & qu==4) | (region=="BB" & year==2006 & qu==1) | (region=="BB" & year==2006 & qu==2) | (region=="BB" & year==2006 & qu==3) | (region=="BB" & year==2006 & qu==4) | (region=="BB" & year==2007 & qu==1) | (region=="BB" & year==2007 & qu==2) | (region=="BB" & year==2007 & qu==3) | (region=="BB" & year==2007 & qu==4) | (region=="BB" & year==2012 & qu==3) | (region=="BB" & year==2012 & qu==4) | (region=="BB" & year==2013 & qu==1) 
replace isbubbly=1 if  (region=="BD" & year==2001 & qu==2) | (region=="BD" & year==2001 & qu==3) | (region=="BD" & year==2001 & qu==4) | (region=="BD" & year==2002 & qu==1) | (region=="BD" & year==2002 & qu==2) | (region=="BD" & year==2002 & qu==3) | (region=="BD" & year==2002 & qu==4) | (region=="BD" & year==2003 & qu==1) | (region=="BD" & year==2003 & qu==2) | (region=="BD" & year==2003 & qu==3) | (region=="BD" & year==2003 & qu==4) | (region=="BD" & year==2004 & qu==1) | (region=="BD" & year==2004 & qu==2) | (region=="BD" & year==2004 & qu==3) | (region=="BD" & year==2004 & qu==4) | (region=="BD" & year==2005 & qu==2) | (region=="BD" & year==2005 & qu==3) | (region=="BD" & year==2005 & qu==4) | (region=="BD" & year==2006 & qu==1) | (region=="BD" & year==2006 & qu==2) | (region=="BD" & year==2006 & qu==3) | (region=="BD" & year==2006 & qu==4) | (region=="BD" & year==2007 & qu==1) | (region=="BD" & year==2007 & qu==2) | (region=="BD" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="BH" & year==1999 & qu==2) | (region=="BH" & year==1999 & qu==3) | (region=="BH" & year==1999 & qu==4) | (region=="BH" & year==2000 & qu==1) | (region=="BH" & year==2000 & qu==2) | (region=="BH" & year==2000 & qu==3) | (region=="BH" & year==2000 & qu==4) | (region=="BH" & year==2001 & qu==2) | (region=="BH" & year==2001 & qu==3) | (region=="BH" & year==2001 & qu==4) | (region=="BH" & year==2002 & qu==1) | (region=="BH" & year==2002 & qu==2) | (region=="BH" & year==2002 & qu==3) | (region=="BH" & year==2002 & qu==4) | (region=="BH" & year==2003 & qu==1) | (region=="BH" & year==2003 & qu==2) | (region=="BH" & year==2003 & qu==3) | (region=="BH" & year==2003 & qu==4) | (region=="BH" & year==2004 & qu==1) | (region=="BH" & year==2004 & qu==2) | (region=="BH" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="BL" & year==2001 & qu==1) | (region=="BL" & year==2001 & qu==2) | (region=="BL" & year==2001 & qu==3) | (region=="BL" & year==2001 & qu==4) | (region=="BL" & year==2002 & qu==1) | (region=="BL" & year==2002 & qu==2) | (region=="BL" & year==2002 & qu==3) | (region=="BL" & year==2002 & qu==4) | (region=="BL" & year==2003 & qu==1) | (region=="BL" & year==2003 & qu==2) | (region=="BL" & year==2003 & qu==3) | (region=="BL" & year==2003 & qu==4) | (region=="BL" & year==2004 & qu==1) | (region=="BL" & year==2004 & qu==2) | (region=="BL" & year==2004 & qu==3) | (region=="BL" & year==2004 & qu==4) | (region=="BL" & year==2005 & qu==1) | (region=="BL" & year==2005 & qu==2) | (region=="BL" & year==2005 & qu==3) | (region=="BL" & year==2005 & qu==4) | (region=="BL" & year==2006 & qu==1) | (region=="BL" & year==2006 & qu==2) | (region=="BL" & year==2006 & qu==3) | (region=="BL" & year==2006 & qu==4) | (region=="BL" & year==2007 & qu==1) | (region=="BL" & year==2007 & qu==2) | (region=="BL" & year==2007 & qu==3) | (region=="BL" & year==2007 & qu==4) | (region=="BL" & year==2008 & qu==1) | (region=="BL" & year==2008 & qu==2) 
replace isbubbly=1 if  (region=="BN" & year==1999 & qu==2) | (region=="BN" & year==1999 & qu==3) | (region=="BN" & year==1999 & qu==4) | (region=="BN" & year==2000 & qu==1) | (region=="BN" & year==2000 & qu==2) | (region=="BN" & year==2000 & qu==3) | (region=="BN" & year==2000 & qu==4) | (region=="BN" & year==2001 & qu==2) | (region=="BN" & year==2001 & qu==3) | (region=="BN" & year==2001 & qu==4) | (region=="BN" & year==2002 & qu==1) | (region=="BN" & year==2002 & qu==2) | (region=="BN" & year==2002 & qu==3) | (region=="BN" & year==2002 & qu==4) | (region=="BN" & year==2003 & qu==1) | (region=="BN" & year==2003 & qu==2) | (region=="BN" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="BR" & year==1999 & qu==2) | (region=="BR" & year==1999 & qu==3) | (region=="BR" & year==1999 & qu==4) | (region=="BR" & year==2000 & qu==1) | (region=="BR" & year==2000 & qu==2) | (region=="BR" & year==2000 & qu==3) | (region=="BR" & year==2000 & qu==4) | (region=="BR" & year==2002 & qu==3) | (region=="BR" & year==2002 & qu==4) | (region=="BR" & year==2003 & qu==1) | (region=="BR" & year==2003 & qu==2) | (region=="BR" & year==2007 & qu==3) | (region=="BR" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="BS" & year==1999 & qu==1) | (region=="BS" & year==1999 & qu==2) | (region=="BS" & year==1999 & qu==3) | (region=="BS" & year==1999 & qu==4) | (region=="BS" & year==2000 & qu==1) | (region=="BS" & year==2000 & qu==2) | (region=="BS" & year==2000 & qu==3) | (region=="BS" & year==2000 & qu==4) | (region=="BS" & year==2001 & qu==1) | (region=="BS" & year==2001 & qu==2) | (region=="BS" & year==2001 & qu==3) | (region=="BS" & year==2001 & qu==4) | (region=="BS" & year==2002 & qu==1) | (region=="BS" & year==2002 & qu==2) | (region=="BS" & year==2002 & qu==3) | (region=="BS" & year==2002 & qu==4) | (region=="BS" & year==2003 & qu==1) | (region=="BS" & year==2003 & qu==2) | (region=="BS" & year==2003 & qu==3) | (region=="BS" & year==2003 & qu==4) | (region=="BS" & year==2004 & qu==1) | (region=="BS" & year==2004 & qu==2) | (region=="BS" & year==2004 & qu==3) | (region=="BS" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="CA" & year==1999 & qu==2) | (region=="CA" & year==1999 & qu==3) | (region=="CA" & year==1999 & qu==4) | (region=="CA" & year==2000 & qu==1) | (region=="CA" & year==2000 & qu==2) | (region=="CA" & year==2000 & qu==3) | (region=="CA" & year==2000 & qu==4) | (region=="CA" & year==2001 & qu==1) | (region=="CA" & year==2001 & qu==3) | (region=="CA" & year==2001 & qu==4) | (region=="CA" & year==2002 & qu==1) | (region=="CA" & year==2002 & qu==2) | (region=="CA" & year==2002 & qu==3) | (region=="CA" & year==2002 & qu==4) | (region=="CA" & year==2003 & qu==1) | (region=="CA" & year==2003 & qu==2) | (region=="CA" & year==2003 & qu==3) | (region=="CA" & year==2003 & qu==4) | (region=="CA" & year==2004 & qu==1) | (region=="CA" & year==2004 & qu==2) | (region=="CA" & year==2004 & qu==3) | (region=="CA" & year==2004 & qu==4) | (region=="CA" & year==2012 & qu==1) | (region=="CA" & year==2012 & qu==2) | (region=="CA" & year==2012 & qu==3) | (region=="CA" & year==2012 & qu==4) 
replace isbubbly=1 if  (region=="CB" & year==1999 & qu==2) | (region=="CB" & year==1999 & qu==3) | (region=="CB" & year==1999 & qu==4) | (region=="CB" & year==2000 & qu==1) | (region=="CB" & year==2000 & qu==2) | (region=="CB" & year==2000 & qu==3) | (region=="CB" & year==2000 & qu==4) | (region=="CB" & year==2001 & qu==1) | (region=="CB" & year==2001 & qu==2) | (region=="CB" & year==2001 & qu==3) | (region=="CB" & year==2001 & qu==4) | (region=="CB" & year==2002 & qu==1) | (region=="CB" & year==2002 & qu==2) | (region=="CB" & year==2002 & qu==3) | (region=="CB" & year==2002 & qu==4) | (region=="CB" & year==2003 & qu==1) | (region=="CB" & year==2003 & qu==2) | (region=="CB" & year==2003 & qu==3) | (region=="CB" & year==2003 & qu==4) | (region=="CB" & year==2004 & qu==1) | (region=="CB" & year==2004 & qu==2) | (region=="CB" & year==2004 & qu==3) | (region=="CB" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="CF" & year==1999 & qu==1) | (region=="CF" & year==1999 & qu==2) | (region=="CF" & year==1999 & qu==3) | (region=="CF" & year==2000 & qu==1) | (region=="CF" & year==2000 & qu==2) | (region=="CF" & year==2000 & qu==3) | (region=="CF" & year==2000 & qu==4) | (region=="CF" & year==2001 & qu==1) | (region=="CF" & year==2001 & qu==2) | (region=="CF" & year==2001 & qu==3) | (region=="CF" & year==2001 & qu==4) | (region=="CF" & year==2002 & qu==1) | (region=="CF" & year==2002 & qu==2) | (region=="CF" & year==2002 & qu==3) | (region=="CF" & year==2002 & qu==4) | (region=="CF" & year==2003 & qu==1) | (region=="CF" & year==2003 & qu==2) | (region=="CF" & year==2003 & qu==3) | (region=="CF" & year==2003 & qu==4) | (region=="CF" & year==2004 & qu==1) | (region=="CF" & year==2004 & qu==2) | (region=="CF" & year==2004 & qu==3) | (region=="CF" & year==2004 & qu==4) | (region=="CF" & year==2005 & qu==1) | (region=="CF" & year==2005 & qu==2) | (region=="CF" & year==2005 & qu==3) | (region=="CF" & year==2005 & qu==4) | (region=="CF" & year==2006 & qu==1) | (region=="CF" & year==2006 & qu==2) | (region=="CF" & year==2006 & qu==3) | (region=="CF" & year==2006 & qu==4) | (region=="CF" & year==2007 & qu==2) | (region=="CF" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="CH" & year==1999 & qu==1) | (region=="CH" & year==1999 & qu==2) | (region=="CH" & year==1999 & qu==3) | (region=="CH" & year==1999 & qu==4) | (region=="CH" & year==2000 & qu==1) | (region=="CH" & year==2000 & qu==2) | (region=="CH" & year==2000 & qu==3) | (region=="CH" & year==2000 & qu==4) | (region=="CH" & year==2001 & qu==1) | (region=="CH" & year==2001 & qu==2) | (region=="CH" & year==2001 & qu==3) | (region=="CH" & year==2001 & qu==4) | (region=="CH" & year==2002 & qu==1) | (region=="CH" & year==2002 & qu==2) | (region=="CH" & year==2002 & qu==3) | (region=="CH" & year==2002 & qu==4) | (region=="CH" & year==2003 & qu==1) | (region=="CH" & year==2003 & qu==2) | (region=="CH" & year==2003 & qu==3) | (region=="CH" & year==2003 & qu==4) | (region=="CH" & year==2004 & qu==1) | (region=="CH" & year==2004 & qu==2) | (region=="CH" & year==2004 & qu==3) | (region=="CH" & year==2004 & qu==4) | (region=="CH" & year==2005 & qu==1) | (region=="CH" & year==2005 & qu==2) | (region=="CH" & year==2005 & qu==3) | (region=="CH" & year==2005 & qu==4) | (region=="CH" & year==2006 & qu==1) | (region=="CH" & year==2006 & qu==2) | (region=="CH" & year==2006 & qu==3) | (region=="CH" & year==2006 & qu==4) | (region=="CH" & year==2007 & qu==2) | (region=="CH" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="CM" & year==1999 & qu==1) | (region=="CM" & year==1999 & qu==2) | (region=="CM" & year==1999 & qu==3) | (region=="CM" & year==1999 & qu==4) | (region=="CM" & year==2000 & qu==1) | (region=="CM" & year==2000 & qu==2) | (region=="CM" & year==2000 & qu==3) | (region=="CM" & year==2000 & qu==4) | (region=="CM" & year==2001 & qu==1) | (region=="CM" & year==2001 & qu==2) | (region=="CM" & year==2001 & qu==3) | (region=="CM" & year==2001 & qu==4) | (region=="CM" & year==2002 & qu==1) | (region=="CM" & year==2002 & qu==2) | (region=="CM" & year==2002 & qu==3) | (region=="CM" & year==2002 & qu==4) | (region=="CM" & year==2003 & qu==1) | (region=="CM" & year==2003 & qu==2) | (region=="CM" & year==2003 & qu==3) | (region=="CM" & year==2003 & qu==4) | (region=="CM" & year==2004 & qu==1) | (region=="CM" & year==2004 & qu==2) | (region=="CM" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="CO" & year==1999 & qu==1) | (region=="CO" & year==1999 & qu==2) | (region=="CO" & year==1999 & qu==3) | (region=="CO" & year==1999 & qu==4) | (region=="CO" & year==2000 & qu==1) | (region=="CO" & year==2000 & qu==2) | (region=="CO" & year==2000 & qu==3) | (region=="CO" & year==2000 & qu==4) | (region=="CO" & year==2001 & qu==1) | (region=="CO" & year==2001 & qu==2) | (region=="CO" & year==2001 & qu==3) | (region=="CO" & year==2001 & qu==4) | (region=="CO" & year==2002 & qu==1) | (region=="CO" & year==2002 & qu==2) | (region=="CO" & year==2002 & qu==3) | (region=="CO" & year==2002 & qu==4) | (region=="CO" & year==2003 & qu==1) | (region=="CO" & year==2003 & qu==2) | (region=="CO" & year==2003 & qu==3) | (region=="CO" & year==2003 & qu==4) | (region=="CO" & year==2004 & qu==1) | (region=="CO" & year==2004 & qu==2) | (region=="CO" & year==2004 & qu==3) | (region=="CO" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="CR" & year==1999 & qu==2) | (region=="CR" & year==1999 & qu==3) | (region=="CR" & year==1999 & qu==4) | (region=="CR" & year==2000 & qu==1) | (region=="CR" & year==2000 & qu==2) | (region=="CR" & year==2000 & qu==3) | (region=="CR" & year==2002 & qu==3) | (region=="CR" & year==2002 & qu==4) | (region=="CR" & year==2003 & qu==1) | (region=="CR" & year==2003 & qu==2) | (region=="CR" & year==2007 & qu==3) | (region=="CR" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="CT" & year==1999 & qu==1) | (region=="CT" & year==1999 & qu==2) | (region=="CT" & year==1999 & qu==3) | (region=="CT" & year==1999 & qu==4) | (region=="CT" & year==2000 & qu==1) | (region=="CT" & year==2000 & qu==2) | (region=="CT" & year==2000 & qu==3) | (region=="CT" & year==2000 & qu==4) | (region=="CT" & year==2001 & qu==1) | (region=="CT" & year==2001 & qu==2) | (region=="CT" & year==2001 & qu==3) | (region=="CT" & year==2001 & qu==4) | (region=="CT" & year==2002 & qu==1) | (region=="CT" & year==2002 & qu==2) | (region=="CT" & year==2002 & qu==3) | (region=="CT" & year==2002 & qu==4) | (region=="CT" & year==2003 & qu==1) | (region=="CT" & year==2003 & qu==2) | (region=="CT" & year==2003 & qu==3) | (region=="CT" & year==2003 & qu==4) | (region=="CT" & year==2004 & qu==1) | (region=="CT" & year==2004 & qu==2) | (region=="CT" & year==2004 & qu==3) | (region=="CT" & year==2004 & qu==4) | (region=="CT" & year==2005 & qu==1) 
replace isbubbly=1 if  (region=="CV" & year==1999 & qu==1) | (region=="CV" & year==1999 & qu==2) | (region=="CV" & year==1999 & qu==3) | (region=="CV" & year==1999 & qu==4) | (region=="CV" & year==2000 & qu==1) | (region=="CV" & year==2000 & qu==2) | (region=="CV" & year==2000 & qu==3) | (region=="CV" & year==2000 & qu==4) | (region=="CV" & year==2001 & qu==1) | (region=="CV" & year==2001 & qu==2) | (region=="CV" & year==2001 & qu==3) | (region=="CV" & year==2001 & qu==4) | (region=="CV" & year==2002 & qu==1) | (region=="CV" & year==2002 & qu==2) | (region=="CV" & year==2002 & qu==3) | (region=="CV" & year==2002 & qu==4) | (region=="CV" & year==2003 & qu==1) | (region=="CV" & year==2003 & qu==2) | (region=="CV" & year==2003 & qu==3) | (region=="CV" & year==2003 & qu==4) | (region=="CV" & year==2004 & qu==1) | (region=="CV" & year==2004 & qu==2) | (region=="CV" & year==2004 & qu==3) | (region=="CV" & year==2004 & qu==4) | (region=="CV" & year==2005 & qu==1) | (region=="CV" & year==2005 & qu==2) | (region=="CV" & year==2005 & qu==3) 
replace isbubbly=1 if  (region=="CW" & year==1999 & qu==3) | (region=="CW" & year==1999 & qu==4) | (region=="CW" & year==2000 & qu==1) | (region=="CW" & year==2000 & qu==2) | (region=="CW" & year==2000 & qu==3) | (region=="CW" & year==2000 & qu==4) | (region=="CW" & year==2001 & qu==1) | (region=="CW" & year==2001 & qu==2) | (region=="CW" & year==2001 & qu==3) | (region=="CW" & year==2001 & qu==4) | (region=="CW" & year==2002 & qu==1) | (region=="CW" & year==2002 & qu==2) | (region=="CW" & year==2002 & qu==3) | (region=="CW" & year==2002 & qu==4) | (region=="CW" & year==2003 & qu==1) | (region=="CW" & year==2003 & qu==2) | (region=="CW" & year==2003 & qu==3) | (region=="CW" & year==2003 & qu==4) | (region=="CW" & year==2004 & qu==1) | (region=="CW" & year==2004 & qu==2) | (region=="CW" & year==2004 & qu==3) | (region=="CW" & year==2004 & qu==4) | (region=="CW" & year==2005 & qu==1) | (region=="CW" & year==2005 & qu==2) | (region=="CW" & year==2005 & qu==3) | (region=="CW" & year==2005 & qu==4) | (region=="CW" & year==2006 & qu==1) | (region=="CW" & year==2006 & qu==2) | (region=="CW" & year==2006 & qu==3) 
replace isbubbly=1 if  (region=="DA" & year==1999 & qu==1) | (region=="DA" & year==1999 & qu==2) | (region=="DA" & year==1999 & qu==3) | (region=="DA" & year==1999 & qu==4) | (region=="DA" & year==2000 & qu==1) | (region=="DA" & year==2000 & qu==2) | (region=="DA" & year==2000 & qu==3) | (region=="DA" & year==2000 & qu==4) | (region=="DA" & year==2001 & qu==1) | (region=="DA" & year==2001 & qu==2) | (region=="DA" & year==2001 & qu==3) | (region=="DA" & year==2001 & qu==4) | (region=="DA" & year==2002 & qu==1) | (region=="DA" & year==2002 & qu==2) | (region=="DA" & year==2002 & qu==3) | (region=="DA" & year==2002 & qu==4) | (region=="DA" & year==2003 & qu==1) | (region=="DA" & year==2003 & qu==2) | (region=="DA" & year==2003 & qu==3) | (region=="DA" & year==2003 & qu==4) | (region=="DA" & year==2004 & qu==1) | (region=="DA" & year==2004 & qu==2) | (region=="DA" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="DE" & year==1999 & qu==2) | (region=="DE" & year==1999 & qu==3) | (region=="DE" & year==1999 & qu==4) | (region=="DE" & year==2000 & qu==1) | (region=="DE" & year==2000 & qu==2) | (region=="DE" & year==2000 & qu==3) | (region=="DE" & year==2000 & qu==4) | (region=="DE" & year==2001 & qu==1) | (region=="DE" & year==2001 & qu==2) | (region=="DE" & year==2001 & qu==3) | (region=="DE" & year==2001 & qu==4) | (region=="DE" & year==2002 & qu==1) | (region=="DE" & year==2002 & qu==2) | (region=="DE" & year==2002 & qu==3) | (region=="DE" & year==2002 & qu==4) | (region=="DE" & year==2003 & qu==1) | (region=="DE" & year==2003 & qu==2) | (region=="DE" & year==2003 & qu==3) | (region=="DE" & year==2003 & qu==4) | (region=="DE" & year==2004 & qu==1) | (region=="DE" & year==2004 & qu==2) | (region=="DE" & year==2004 & qu==3) | (region=="DE" & year==2004 & qu==4) | (region=="DE" & year==2005 & qu==1) | (region=="DE" & year==2005 & qu==2) | (region=="DE" & year==2005 & qu==3) 
replace isbubbly=1 if  (region=="DH" & year==2002 & qu==1) | (region=="DH" & year==2002 & qu==2) | (region=="DH" & year==2002 & qu==3) | (region=="DH" & year==2002 & qu==4) | (region=="DH" & year==2003 & qu==1) | (region=="DH" & year==2003 & qu==2) | (region=="DH" & year==2003 & qu==3) | (region=="DH" & year==2003 & qu==4) | (region=="DH" & year==2004 & qu==1) | (region=="DH" & year==2004 & qu==2) | (region=="DH" & year==2004 & qu==3) | (region=="DH" & year==2004 & qu==4) | (region=="DH" & year==2005 & qu==1) | (region=="DH" & year==2005 & qu==2) | (region=="DH" & year==2005 & qu==3) | (region=="DH" & year==2005 & qu==4) | (region=="DH" & year==2006 & qu==1) | (region=="DH" & year==2006 & qu==2) | (region=="DH" & year==2006 & qu==3) 
replace isbubbly=1 if  (region=="DL" & year==2001 & qu==3) | (region=="DL" & year==2001 & qu==4) | (region=="DL" & year==2002 & qu==1) | (region=="DL" & year==2002 & qu==2) | (region=="DL" & year==2002 & qu==3) | (region=="DL" & year==2002 & qu==4) | (region=="DL" & year==2003 & qu==1) | (region=="DL" & year==2003 & qu==2) | (region=="DL" & year==2003 & qu==3) | (region=="DL" & year==2003 & qu==4) | (region=="DL" & year==2004 & qu==1) | (region=="DL" & year==2004 & qu==2) | (region=="DL" & year==2004 & qu==3) | (region=="DL" & year==2004 & qu==4) | (region=="DL" & year==2005 & qu==1) | (region=="DL" & year==2005 & qu==2) | (region=="DL" & year==2005 & qu==3) | (region=="DL" & year==2005 & qu==4) | (region=="DL" & year==2006 & qu==1) | (region=="DL" & year==2006 & qu==2) | (region=="DL" & year==2006 & qu==3) | (region=="DL" & year==2006 & qu==4) | (region=="DL" & year==2007 & qu==1) | (region=="DL" & year==2007 & qu==2) | (region=="DL" & year==2007 & qu==3) | (region=="DL" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="DN" & year==1999 & qu==4) | (region=="DN" & year==2000 & qu==1) | (region=="DN" & year==2000 & qu==2) | (region=="DN" & year==2000 & qu==3) | (region=="DN" & year==2000 & qu==4) | (region=="DN" & year==2001 & qu==1) | (region=="DN" & year==2001 & qu==2) | (region=="DN" & year==2001 & qu==3) | (region=="DN" & year==2001 & qu==4) | (region=="DN" & year==2002 & qu==1) | (region=="DN" & year==2002 & qu==2) | (region=="DN" & year==2002 & qu==3) | (region=="DN" & year==2002 & qu==4) | (region=="DN" & year==2003 & qu==1) | (region=="DN" & year==2003 & qu==2) | (region=="DN" & year==2003 & qu==3) | (region=="DN" & year==2003 & qu==4) | (region=="DN" & year==2004 & qu==1) | (region=="DN" & year==2004 & qu==2) | (region=="DN" & year==2004 & qu==3) | (region=="DN" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="DT" & year==1999 & qu==1) | (region=="DT" & year==1999 & qu==2) | (region=="DT" & year==1999 & qu==3) | (region=="DT" & year==1999 & qu==4) | (region=="DT" & year==2000 & qu==1) | (region=="DT" & year==2000 & qu==2) | (region=="DT" & year==2000 & qu==3) | (region=="DT" & year==2000 & qu==4) | (region=="DT" & year==2001 & qu==1) | (region=="DT" & year==2001 & qu==2) | (region=="DT" & year==2001 & qu==3) | (region=="DT" & year==2001 & qu==4) | (region=="DT" & year==2002 & qu==1) | (region=="DT" & year==2002 & qu==2) | (region=="DT" & year==2002 & qu==3) | (region=="DT" & year==2002 & qu==4) | (region=="DT" & year==2003 & qu==1) | (region=="DT" & year==2003 & qu==2) | (region=="DT" & year==2003 & qu==3) | (region=="DT" & year==2003 & qu==4) | (region=="DT" & year==2004 & qu==1) | (region=="DT" & year==2004 & qu==2) | (region=="DT" & year==2004 & qu==3) | (region=="DT" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="DY" & year==2000 & qu==2) | (region=="DY" & year==2000 & qu==3) | (region=="DY" & year==2000 & qu==4) | (region=="DY" & year==2001 & qu==1) | (region=="DY" & year==2001 & qu==2) | (region=="DY" & year==2001 & qu==3) | (region=="DY" & year==2001 & qu==4) | (region=="DY" & year==2002 & qu==1) | (region=="DY" & year==2002 & qu==2) | (region=="DY" & year==2002 & qu==3) | (region=="DY" & year==2002 & qu==4) | (region=="DY" & year==2003 & qu==1) | (region=="DY" & year==2003 & qu==2) | (region=="DY" & year==2003 & qu==3) | (region=="DY" & year==2003 & qu==4) | (region=="DY" & year==2004 & qu==1) | (region=="DY" & year==2004 & qu==2) | (region=="DY" & year==2004 & qu==3) | (region=="DY" & year==2004 & qu==4) | (region=="DY" & year==2005 & qu==1) | (region=="DY" & year==2005 & qu==2) | (region=="DY" & year==2005 & qu==3) | (region=="DY" & year==2005 & qu==4) 
replace isbubbly=1 if  (region=="E"  & year==1999 & qu==1) | (region=="E"  & year==1999 & qu==2) | (region=="E"  & year==1999 & qu==3) | (region=="E"  & year==1999 & qu==4) | (region=="E"  & year==2000 & qu==1) | (region=="E"  & year==2000 & qu==2) | (region=="E" & year==2000 & qu==3) | (region=="E" & year==2000 & qu==4) | (region=="E" & year==2001 & qu==1) | (region=="E" & year==2001 & qu==2) | (region=="E" & year==2001 & qu==3) | (region=="E" & year==2001 & qu==4) | (region=="E" & year==2002 & qu==1) | (region=="E" & year==2002 & qu==2) | (region=="E" & year==2002 & qu==3) | (region=="E" & year==2002 & qu==4) | (region=="E" & year==2003 & qu==1) | (region=="E" & year==2003 & qu==2) | (region=="E" & year==2003 & qu==3) | (region=="E" & year==2003 & qu==4) | (region=="E" & year==2004 & qu==1) | (region=="E" & year==2004 & qu==2) | (region=="E" & year==2004 & qu==3) | (region=="E" & year==2004 & qu==4) | (region=="E" & year==2007 & qu==2) | (region=="E" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="EN" & year==1999 & qu==3) | (region=="EN" & year==1999 & qu==4) | (region=="EN" & year==2000 & qu==1) | (region=="EN" & year==2000 & qu==2) | (region=="EN" & year==2000 & qu==3) | (region=="EN" & year==2001 & qu==4) | (region=="EN" & year==2002 & qu==1) | (region=="EN" & year==2002 & qu==2) | (region=="EN" & year==2002 & qu==3) | (region=="EN" & year==2002 & qu==4) | (region=="EN" & year==2003 & qu==1) | (region=="EN" & year==2003 & qu==2) | (region=="EN" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="EX" & year==1999 & qu==1) | (region=="EX" & year==1999 & qu==2) | (region=="EX" & year==1999 & qu==3) | (region=="EX" & year==1999 & qu==4) | (region=="EX" & year==2000 & qu==1) | (region=="EX" & year==2000 & qu==2) | (region=="EX" & year==2000 & qu==3) | (region=="EX" & year==2000 & qu==4) | (region=="EX" & year==2001 & qu==1) | (region=="EX" & year==2001 & qu==2) | (region=="EX" & year==2001 & qu==3) | (region=="EX" & year==2001 & qu==4) | (region=="EX" & year==2002 & qu==1) | (region=="EX" & year==2002 & qu==2) | (region=="EX" & year==2002 & qu==3) | (region=="EX" & year==2002 & qu==4) | (region=="EX" & year==2003 & qu==1) | (region=="EX" & year==2003 & qu==2) | (region=="EX" & year==2003 & qu==3) | (region=="EX" & year==2003 & qu==4) | (region=="EX" & year==2004 & qu==1) | (region=="EX" & year==2004 & qu==2) | (region=="EX" & year==2004 & qu==3) | (region=="EX" & year==2004 & qu==4) | (region=="EX" & year==2005 & qu==1) 
replace isbubbly=1 if  (region=="FY" & year==2000 & qu==3) | (region=="FY" & year==2000 & qu==4) | (region=="FY" & year==2001 & qu==1) | (region=="FY" & year==2001 & qu==2) | (region=="FY" & year==2001 & qu==3) | (region=="FY" & year==2001 & qu==4) | (region=="FY" & year==2002 & qu==1) | (region=="FY" & year==2002 & qu==2) | (region=="FY" & year==2002 & qu==3) | (region=="FY" & year==2002 & qu==4) | (region=="FY" & year==2003 & qu==1) | (region=="FY" & year==2003 & qu==2) | (region=="FY" & year==2003 & qu==3) | (region=="FY" & year==2003 & qu==4) | (region=="FY" & year==2004 & qu==1) | (region=="FY" & year==2004 & qu==2) | (region=="FY" & year==2004 & qu==3) | (region=="FY" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="GL" & year==1999 & qu==1) | (region=="GL" & year==1999 & qu==2) | (region=="GL" & year==1999 & qu==3) | (region=="GL" & year==1999 & qu==4) | (region=="GL" & year==2000 & qu==1) | (region=="GL" & year==2000 & qu==2) | (region=="GL" & year==2000 & qu==3) | (region=="GL" & year==2000 & qu==4) | (region=="GL" & year==2001 & qu==1) | (region=="GL" & year==2001 & qu==2) | (region=="GL" & year==2001 & qu==3) | (region=="GL" & year==2001 & qu==4) | (region=="GL" & year==2002 & qu==1) | (region=="GL" & year==2002 & qu==2) | (region=="GL" & year==2002 & qu==3) | (region=="GL" & year==2002 & qu==4) | (region=="GL" & year==2003 & qu==1) | (region=="GL" & year==2003 & qu==2) | (region=="GL" & year==2003 & qu==3) | (region=="GL" & year==2003 & qu==4) | (region=="GL" & year==2004 & qu==1) | (region=="GL" & year==2004 & qu==2) | (region=="GL" & year==2004 & qu==3) | (region=="GL" & year==2004 & qu==4) | (region=="GL" & year==2005 & qu==1) 
replace isbubbly=1 if  (region=="GU" & year==1999 & qu==3) | (region=="GU" & year==1999 & qu==4) | (region=="GU" & year==2000 & qu==1) | (region=="GU" & year==2000 & qu==2) | (region=="GU" & year==2000 & qu==3) | (region=="GU" & year==2002 & qu==3) | (region=="GU" & year==2002 & qu==4) | (region=="GU" & year==2007 & qu==2) | (region=="GU" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="HA" & year==1999 & qu==3) | (region=="HA" & year==1999 & qu==4) | (region=="HA" & year==2000 & qu==1) | (region=="HA" & year==2000 & qu==2) | (region=="HA" & year==2000 & qu==3) | (region=="HA" & year==2000 & qu==4) | (region=="HA" & year==2001 & qu==1) | (region=="HA" & year==2002 & qu==1) | (region=="HA" & year==2002 & qu==2) | (region=="HA" & year==2002 & qu==3) | (region=="HA" & year==2002 & qu==4) | (region=="HA" & year==2003 & qu==1) | (region=="HA" & year==2003 & qu==2) | (region=="HA" & year==2003 & qu==3) | (region=="HA" & year==2007 & qu==2) | (region=="HA" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="HD" & year==2002 & qu==2) | (region=="HD" & year==2002 & qu==3) | (region=="HD" & year==2002 & qu==4) | (region=="HD" & year==2003 & qu==1) | (region=="HD" & year==2003 & qu==2) | (region=="HD" & year==2003 & qu==3) | (region=="HD" & year==2003 & qu==4) | (region=="HD" & year==2004 & qu==1) | (region=="HD" & year==2004 & qu==2) | (region=="HD" & year==2004 & qu==3) | (region=="HD" & year==2004 & qu==4) | (region=="HD" & year==2005 & qu==1) | (region=="HD" & year==2005 & qu==2) | (region=="HD" & year==2005 & qu==3) | (region=="HD" & year==2005 & qu==4) | (region=="HD" & year==2006 & qu==1) | (region=="HD" & year==2006 & qu==2) | (region=="HD" & year==2006 & qu==3) | (region=="HD" & year==2006 & qu==4) | (region=="HD" & year==2007 & qu==1) | (region=="HD" & year==2007 & qu==2) | (region=="HD" & year==2007 & qu==3) | (region=="HD" & year==2007 & qu==4) | (region=="HD" & year==2008 & qu==1) 
replace isbubbly=1 if  (region=="HG" & year==1999 & qu==3) | (region=="HG" & year==1999 & qu==4) | (region=="HG" & year==2000 & qu==1) | (region=="HG" & year==2000 & qu==2) | (region=="HG" & year==2000 & qu==3) | (region=="HG" & year==2000 & qu==4) | (region=="HG" & year==2001 & qu==1) | (region=="HG" & year==2001 & qu==2) | (region=="HG" & year==2001 & qu==3) | (region=="HG" & year==2001 & qu==4) | (region=="HG" & year==2002 & qu==1) | (region=="HG" & year==2002 & qu==2) | (region=="HG" & year==2002 & qu==3) | (region=="HG" & year==2002 & qu==4) | (region=="HG" & year==2003 & qu==1) | (region=="HG" & year==2003 & qu==2) | (region=="HG" & year==2003 & qu==3) | (region=="HG" & year==2003 & qu==4) | (region=="HG" & year==2004 & qu==1) | (region=="HG" & year==2004 & qu==2) | (region=="HG" & year==2004 & qu==3) | (region=="HG" & year==2004 & qu==4) | (region=="HG" & year==2005 & qu==1) | (region=="HG" & year==2005 & qu==2) | (region=="HG" & year==2005 & qu==3) | (region=="HG" & year==2005 & qu==4) | (region=="HG" & year==2006 & qu==1) | (region=="HG" & year==2006 & qu==2) | (region=="HG" & year==2006 & qu==3) | (region=="HG" & year==2006 & qu==4) | (region=="HG" & year==2007 & qu==1) | (region=="HG" & year==2007 & qu==2) | (region=="HG" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="HP" & year==1999 & qu==3) | (region=="HP" & year==1999 & qu==4) | (region=="HP" & year==2000 & qu==1) | (region=="HP" & year==2000 & qu==2) | (region=="HP" & year==2000 & qu==3) | (region=="HP" & year==2002 & qu==3) | (region=="HP" & year==2002 & qu==4) | (region=="HP" & year==2003 & qu==1) 
replace isbubbly=1 if  (region=="HU" & year==2001 & qu==3) | (region=="HU" & year==2001 & qu==4) | (region=="HU" & year==2002 & qu==1) | (region=="HU" & year==2002 & qu==2) | (region=="HU" & year==2002 & qu==3) | (region=="HU" & year==2002 & qu==4) | (region=="HU" & year==2003 & qu==1) | (region=="HU" & year==2003 & qu==2) | (region=="HU" & year==2003 & qu==3) | (region=="HU" & year==2003 & qu==4) | (region=="HU" & year==2004 & qu==1) | (region=="HU" & year==2004 & qu==2) | (region=="HU" & year==2004 & qu==3) | (region=="HU" & year==2004 & qu==4) | (region=="HU" & year==2005 & qu==1) | (region=="HU" & year==2005 & qu==2) | (region=="HU" & year==2005 & qu==3) | (region=="HU" & year==2005 & qu==4) | (region=="HU" & year==2006 & qu==1) | (region=="HU" & year==2006 & qu==2) | (region=="HU" & year==2006 & qu==3) | (region=="HU" & year==2006 & qu==4) | (region=="HU" & year==2007 & qu==1) | (region=="HU" & year==2007 & qu==2) | (region=="HU" & year==2007 & qu==3) | (region=="HU" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="HX" & year==2002 & qu==4) | (region=="HX" & year==2003 & qu==1) | (region=="HX" & year==2003 & qu==2) | (region=="HX" & year==2003 & qu==3) | (region=="HX" & year==2003 & qu==4) | (region=="HX" & year==2004 & qu==1) | (region=="HX" & year==2004 & qu==2) | (region=="HX" & year==2004 & qu==3) | (region=="HX" & year==2004 & qu==4) | (region=="HX" & year==2005 & qu==1) | (region=="HX" & year==2005 & qu==2) | (region=="HX" & year==2005 & qu==3) | (region=="HX" & year==2005 & qu==4) | (region=="HX" & year==2006 & qu==1) | (region=="HX" & year==2006 & qu==2) | (region=="HX" & year==2006 & qu==3) | (region=="HX" & year==2006 & qu==4) | (region=="HX" & year==2007 & qu==1) | (region=="HX" & year==2007 & qu==2) | (region=="HX" & year==2007 & qu==3) | (region=="HX" & year==2007 & qu==4) | (region=="HX" & year==2008 & qu==1) | (region=="HX" & year==2008 & qu==2) 
replace isbubbly=1 if  (region=="IG" & year==1999 & qu==1) | (region=="IG" & year==1999 & qu==2) | (region=="IG" & year==1999 & qu==3) | (region=="IG" & year==1999 & qu==4) | (region=="IG" & year==2000 & qu==1) | (region=="IG" & year==2000 & qu==2) | (region=="IG" & year==2000 & qu==3) | (region=="IG" & year==2000 & qu==4) | (region=="IG" & year==2001 & qu==1) | (region=="IG" & year==2001 & qu==2) | (region=="IG" & year==2001 & qu==3) | (region=="IG" & year==2001 & qu==4) | (region=="IG" & year==2002 & qu==1) | (region=="IG" & year==2002 & qu==2) | (region=="IG" & year==2002 & qu==3) | (region=="IG" & year==2002 & qu==4) | (region=="IG" & year==2003 & qu==1) | (region=="IG" & year==2003 & qu==2) | (region=="IG" & year==2003 & qu==3) | (region=="IG" & year==2003 & qu==4) | (region=="IG" & year==2004 & qu==1) | (region=="IG" & year==2004 & qu==2) | (region=="IG" & year==2004 & qu==3) | (region=="IG" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="IP" & year==1999 & qu==1) | (region=="IP" & year==1999 & qu==2) | (region=="IP" & year==1999 & qu==3) | (region=="IP" & year==1999 & qu==4) | (region=="IP" & year==2000 & qu==1) | (region=="IP" & year==2000 & qu==2) | (region=="IP" & year==2000 & qu==3) | (region=="IP" & year==2000 & qu==4) | (region=="IP" & year==2001 & qu==1) | (region=="IP" & year==2001 & qu==2) | (region=="IP" & year==2001 & qu==3) | (region=="IP" & year==2001 & qu==4) | (region=="IP" & year==2002 & qu==1) | (region=="IP" & year==2002 & qu==2) | (region=="IP" & year==2002 & qu==3) | (region=="IP" & year==2002 & qu==4) | (region=="IP" & year==2003 & qu==1) | (region=="IP" & year==2003 & qu==2) | (region=="IP" & year==2003 & qu==3) | (region=="IP" & year==2003 & qu==4) | (region=="IP" & year==2004 & qu==1) | (region=="IP" & year==2004 & qu==2) | (region=="IP" & year==2004 & qu==3) | (region=="IP" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="KT" & year==1999 & qu==2) | (region=="KT" & year==1999 & qu==3) | (region=="KT" & year==1999 & qu==4) | (region=="KT" & year==2000 & qu==1) | (region=="KT" & year==2000 & qu==2) | (region=="KT" & year==2000 & qu==3) | (region=="KT" & year==2000 & qu==4) | (region=="KT" & year==2001 & qu==2) | (region=="KT" & year==2001 & qu==3) | (region=="KT" & year==2002 & qu==3) | (region=="KT" & year==2002 & qu==4) | (region=="KT" & year==2007 & qu==2) | (region=="KT" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="L"  & year==2000 & qu==3) | (region=="L"  & year==2000 & qu==4) | (region=="L"  & year==2001 & qu==1) | (region=="L"  & year==2001 & qu==2) | (region=="L"  & year==2001 & qu==3) | (region=="L"  & year==2001 & qu==4) | (region=="L" & year==2002 & qu==1) | (region=="L" & year==2002 & qu==2) | (region=="L" & year==2002 & qu==3) | (region=="L" & year==2002 & qu==4) | (region=="L" & year==2003 & qu==1) | (region=="L" & year==2003 & qu==2) | (region=="L" & year==2003 & qu==3) | (region=="L" & year==2003 & qu==4) | (region=="L" & year==2004 & qu==1) | (region=="L" & year==2004 & qu==2) | (region=="L" & year==2004 & qu==3) | (region=="L" & year==2004 & qu==4) | (region=="L" & year==2005 & qu==1) | (region=="L" & year==2005 & qu==2) | (region=="L" & year==2005 & qu==3) | (region=="L" & year==2005 & qu==4) | (region=="L" & year==2006 & qu==1) | (region=="L" & year==2006 & qu==2) | (region=="L" & year==2006 & qu==3) 
replace isbubbly=1 if  (region=="LA" & year==2002 & qu==1) | (region=="LA" & year==2002 & qu==2) | (region=="LA" & year==2002 & qu==3) | (region=="LA" & year==2002 & qu==4) | (region=="LA" & year==2003 & qu==1) | (region=="LA" & year==2003 & qu==2) | (region=="LA" & year==2003 & qu==3) | (region=="LA" & year==2003 & qu==4) | (region=="LA" & year==2004 & qu==1) | (region=="LA" & year==2004 & qu==2) | (region=="LA" & year==2004 & qu==3) | (region=="LA" & year==2004 & qu==4) | (region=="LA" & year==2005 & qu==1) | (region=="LA" & year==2005 & qu==2) | (region=="LA" & year==2005 & qu==3) | (region=="LA" & year==2005 & qu==4) | (region=="LA" & year==2006 & qu==1) | (region=="LA" & year==2006 & qu==2) | (region=="LA" & year==2006 & qu==3) | (region=="LA" & year==2006 & qu==4) | (region=="LA" & year==2007 & qu==1) | (region=="LA" & year==2007 & qu==2) | (region=="LA" & year==2007 & qu==3) | (region=="LA" & year==2007 & qu==4) | (region=="LA" & year==2008 & qu==1) | (region=="LA" & year==2008 & qu==2) 
replace isbubbly=1 if  (region=="LE" & year==1999 & qu==1) | (region=="LE" & year==1999 & qu==2) | (region=="LE" & year==1999 & qu==3) | (region=="LE" & year==1999 & qu==4) | (region=="LE" & year==2000 & qu==1) | (region=="LE" & year==2000 & qu==2) | (region=="LE" & year==2000 & qu==3) | (region=="LE" & year==2000 & qu==4) | (region=="LE" & year==2001 & qu==1) | (region=="LE" & year==2001 & qu==2) | (region=="LE" & year==2001 & qu==3) | (region=="LE" & year==2001 & qu==4) | (region=="LE" & year==2002 & qu==1) | (region=="LE" & year==2002 & qu==2) | (region=="LE" & year==2002 & qu==3) | (region=="LE" & year==2002 & qu==4) | (region=="LE" & year==2003 & qu==1) | (region=="LE" & year==2003 & qu==2) | (region=="LE" & year==2003 & qu==3) | (region=="LE" & year==2003 & qu==4) | (region=="LE" & year==2004 & qu==1) | (region=="LE" & year==2004 & qu==2) | (region=="LE" & year==2004 & qu==3) | (region=="LE" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="LL" & year==1999 & qu==3) | (region=="LL" & year==1999 & qu==4) | (region=="LL" & year==2000 & qu==2) | (region=="LL" & year==2000 & qu==3) | (region=="LL" & year==2000 & qu==4) | (region=="LL" & year==2001 & qu==1) | (region=="LL" & year==2001 & qu==2) | (region=="LL" & year==2001 & qu==3) | (region=="LL" & year==2001 & qu==4) | (region=="LL" & year==2002 & qu==1) | (region=="LL" & year==2002 & qu==2) | (region=="LL" & year==2002 & qu==3) | (region=="LL" & year==2002 & qu==4) | (region=="LL" & year==2003 & qu==1) | (region=="LL" & year==2003 & qu==2) | (region=="LL" & year==2003 & qu==3) | (region=="LL" & year==2003 & qu==4) | (region=="LL" & year==2004 & qu==1) | (region=="LL" & year==2004 & qu==2) | (region=="LL" & year==2004 & qu==3) | (region=="LL" & year==2004 & qu==4) | (region=="LL" & year==2005 & qu==1) | (region=="LL" & year==2005 & qu==2) | (region=="LL" & year==2005 & qu==3) | (region=="LL" & year==2005 & qu==4) | (region=="LL" & year==2006 & qu==1) | (region=="LL" & year==2006 & qu==2) | (region=="LL" & year==2006 & qu==3) | (region=="LL" & year==2006 & qu==4) | (region=="LL" & year==2007 & qu==1) 
replace isbubbly=1 if  (region=="LN" & year==2000 & qu==1) | (region=="LN" & year==2000 & qu==2) | (region=="LN" & year==2000 & qu==3) | (region=="LN" & year==2000 & qu==4) | (region=="LN" & year==2001 & qu==1) | (region=="LN" & year==2001 & qu==2) | (region=="LN" & year==2001 & qu==3) | (region=="LN" & year==2001 & qu==4) | (region=="LN" & year==2002 & qu==1) | (region=="LN" & year==2002 & qu==2) | (region=="LN" & year==2002 & qu==3) | (region=="LN" & year==2002 & qu==4) | (region=="LN" & year==2003 & qu==1) | (region=="LN" & year==2003 & qu==2) | (region=="LN" & year==2003 & qu==3) | (region=="LN" & year==2003 & qu==4) | (region=="LN" & year==2004 & qu==1) | (region=="LN" & year==2004 & qu==2) | (region=="LN" & year==2004 & qu==3) | (region=="LN" & year==2004 & qu==4) | (region=="LN" & year==2005 & qu==1) | (region=="LN" & year==2005 & qu==2) | (region=="LN" & year==2005 & qu==3) | (region=="LN" & year==2005 & qu==4) | (region=="LN" & year==2006 & qu==2) | (region=="LN" & year==2006 & qu==3) 
replace isbubbly=1 if  (region=="LS" & year==1999 & qu==2) | (region=="LS" & year==1999 & qu==3) | (region=="LS" & year==1999 & qu==4) | (region=="LS" & year==2000 & qu==1) | (region=="LS" & year==2000 & qu==2) | (region=="LS" & year==2000 & qu==3) | (region=="LS" & year==2000 & qu==4) | (region=="LS" & year==2001 & qu==1) | (region=="LS" & year==2001 & qu==2) | (region=="LS" & year==2001 & qu==3) | (region=="LS" & year==2001 & qu==4) | (region=="LS" & year==2002 & qu==1) | (region=="LS" & year==2002 & qu==2) | (region=="LS" & year==2002 & qu==3) | (region=="LS" & year==2002 & qu==4) | (region=="LS" & year==2003 & qu==1) | (region=="LS" & year==2003 & qu==2) | (region=="LS" & year==2003 & qu==3) | (region=="LS" & year==2003 & qu==4) | (region=="LS" & year==2004 & qu==1) | (region=="LS" & year==2004 & qu==2) | (region=="LS" & year==2004 & qu==3) | (region=="LS" & year==2004 & qu==4) | (region=="LS" & year==2005 & qu==1) | (region=="LS" & year==2005 & qu==2) | (region=="LS" & year==2005 & qu==3) | (region=="LS" & year==2005 & qu==4) | (region=="LS" & year==2006 & qu==1) | (region=="LS" & year==2006 & qu==2) | (region=="LS" & year==2006 & qu==3) | (region=="LS" & year==2006 & qu==4) | (region=="LS" & year==2007 & qu==1) | (region=="LS" & year==2007 & qu==2) | (region=="LS" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="LU" & year==1999 & qu==1) | (region=="LU" & year==1999 & qu==2) | (region=="LU" & year==1999 & qu==3) | (region=="LU" & year==1999 & qu==4) | (region=="LU" & year==2000 & qu==1) | (region=="LU" & year==2000 & qu==2) | (region=="LU" & year==2000 & qu==3) | (region=="LU" & year==2000 & qu==4) | (region=="LU" & year==2001 & qu==1) | (region=="LU" & year==2001 & qu==2) | (region=="LU" & year==2001 & qu==3) | (region=="LU" & year==2001 & qu==4) | (region=="LU" & year==2002 & qu==1) | (region=="LU" & year==2002 & qu==2) | (region=="LU" & year==2002 & qu==3) | (region=="LU" & year==2002 & qu==4) | (region=="LU" & year==2003 & qu==1) | (region=="LU" & year==2003 & qu==2) | (region=="LU" & year==2003 & qu==3) | (region=="LU" & year==2003 & qu==4) | (region=="LU" & year==2004 & qu==1) | (region=="LU" & year==2004 & qu==2) | (region=="LU" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="M"  & year==1999 & qu==3) | (region=="M"  & year==1999 & qu==4) | (region=="M"  & year==2000 & qu==1) | (region=="M"  & year==2000 & qu==2) | (region=="M"  & year==2000 & qu==3) | (region=="M"  & year==2000 & qu==4) | (region=="M" & year==2001 & qu==1) | (region=="M" & year==2001 & qu==2) | (region=="M" & year==2001 & qu==3) | (region=="M" & year==2001 & qu==4) | (region=="M" & year==2002 & qu==1) | (region=="M" & year==2002 & qu==2) | (region=="M" & year==2002 & qu==3) | (region=="M" & year==2002 & qu==4) | (region=="M" & year==2003 & qu==1) | (region=="M" & year==2003 & qu==2) | (region=="M" & year==2003 & qu==3) | (region=="M" & year==2003 & qu==4) | (region=="M" & year==2004 & qu==1) | (region=="M" & year==2004 & qu==2) | (region=="M" & year==2004 & qu==3) | (region=="M" & year==2004 & qu==4) | (region=="M" & year==2005 & qu==1) | (region=="M" & year==2005 & qu==2) | (region=="M" & year==2005 & qu==3) | (region=="M" & year==2005 & qu==4) | (region=="M" & year==2006 & qu==1) | (region=="M" & year==2006 & qu==2) | (region=="M" & year==2006 & qu==3) | (region=="M" & year==2006 & qu==4) | (region=="M" & year==2007 & qu==1) | (region=="M" & year==2007 & qu==2) | (region=="M" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="ME" & year==1999 & qu==1) | (region=="ME" & year==1999 & qu==2) | (region=="ME" & year==1999 & qu==3) | (region=="ME" & year==1999 & qu==4) | (region=="ME" & year==2000 & qu==1) | (region=="ME" & year==2000 & qu==2) | (region=="ME" & year==2000 & qu==3) | (region=="ME" & year==2000 & qu==4) | (region=="ME" & year==2001 & qu==1) | (region=="ME" & year==2001 & qu==2) | (region=="ME" & year==2001 & qu==3) | (region=="ME" & year==2001 & qu==4) | (region=="ME" & year==2002 & qu==1) | (region=="ME" & year==2002 & qu==2) | (region=="ME" & year==2002 & qu==3) | (region=="ME" & year==2002 & qu==4) | (region=="ME" & year==2003 & qu==1) | (region=="ME" & year==2003 & qu==2) | (region=="ME" & year==2003 & qu==3) | (region=="ME" & year==2003 & qu==4) | (region=="ME" & year==2004 & qu==1) | (region=="ME" & year==2004 & qu==2) | (region=="ME" & year==2004 & qu==3) | (region=="ME" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="MK" & year==1999 & qu==2) | (region=="MK" & year==1999 & qu==3) | (region=="MK" & year==1999 & qu==4) | (region=="MK" & year==2000 & qu==1) | (region=="MK" & year==2000 & qu==2) | (region=="MK" & year==2000 & qu==3) | (region=="MK" & year==2000 & qu==4) | (region=="MK" & year==2001 & qu==1) | (region=="MK" & year==2001 & qu==2) | (region=="MK" & year==2001 & qu==3) | (region=="MK" & year==2001 & qu==4) | (region=="MK" & year==2002 & qu==1) | (region=="MK" & year==2002 & qu==2) | (region=="MK" & year==2002 & qu==3) | (region=="MK" & year==2002 & qu==4) | (region=="MK" & year==2003 & qu==1) | (region=="MK" & year==2003 & qu==2) | (region=="MK" & year==2003 & qu==3) | (region=="MK" & year==2003 & qu==4) | (region=="MK" & year==2004 & qu==1) | (region=="MK" & year==2004 & qu==2) | (region=="MK" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="N"  & year==1999 & qu==2) | (region=="N"  & year==1999 & qu==3) | (region=="N"  & year==1999 & qu==4) | (region=="N"  & year==2000 & qu==1) | (region=="N"  & year==2000 & qu==2) | (region=="N"  & year==2000 & qu==3) | (region=="N" & year==2000 & qu==4) | (region=="N" & year==2001 & qu==1) | (region=="N" & year==2001 & qu==2) | (region=="N" & year==2001 & qu==3) | (region=="N" & year==2002 & qu==3) | (region=="N" & year==2002 & qu==4) | (region=="N" & year==2003 & qu==1) | (region=="N" & year==2003 & qu==2) | (region=="N" & year==2003 & qu==3) | (region=="N" & year==2007 & qu==1) | (region=="N" & year==2007 & qu==2) | (region=="N" & year==2007 & qu==3) | (region=="N" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="NE" & year==1999 & qu==3) | (region=="NE" & year==1999 & qu==4) | (region=="NE" & year==2000 & qu==1) | (region=="NE" & year==2000 & qu==2) | (region=="NE" & year==2000 & qu==3) | (region=="NE" & year==2000 & qu==4) | (region=="NE" & year==2001 & qu==1) | (region=="NE" & year==2001 & qu==2) | (region=="NE" & year==2001 & qu==3) | (region=="NE" & year==2001 & qu==4) | (region=="NE" & year==2002 & qu==1) | (region=="NE" & year==2002 & qu==2) | (region=="NE" & year==2002 & qu==3) | (region=="NE" & year==2002 & qu==4) | (region=="NE" & year==2003 & qu==1) | (region=="NE" & year==2003 & qu==2) | (region=="NE" & year==2003 & qu==3) | (region=="NE" & year==2003 & qu==4) | (region=="NE" & year==2004 & qu==1) | (region=="NE" & year==2008 & qu==4) | (region=="NE" & year==2009 & qu==1) | (region=="NE" & year==2012 & qu==1) | (region=="NE" & year==2012 & qu==2) 
replace isbubbly=1 if  (region=="NG" & year==1999 & qu==2) | (region=="NG" & year==1999 & qu==3) | (region=="NG" & year==1999 & qu==4) | (region=="NG" & year==2000 & qu==1) | (region=="NG" & year==2000 & qu==2) | (region=="NG" & year==2000 & qu==3) | (region=="NG" & year==2000 & qu==4) | (region=="NG" & year==2001 & qu==1) | (region=="NG" & year==2001 & qu==2) | (region=="NG" & year==2001 & qu==3) | (region=="NG" & year==2001 & qu==4) | (region=="NG" & year==2002 & qu==1) | (region=="NG" & year==2002 & qu==2) | (region=="NG" & year==2002 & qu==3) | (region=="NG" & year==2002 & qu==4) | (region=="NG" & year==2003 & qu==1) | (region=="NG" & year==2003 & qu==2) | (region=="NG" & year==2003 & qu==3) | (region=="NG" & year==2003 & qu==4) | (region=="NG" & year==2004 & qu==1) | (region=="NG" & year==2004 & qu==2) | (region=="NG" & year==2004 & qu==3) | (region=="NG" & year==2004 & qu==4) | (region=="NG" & year==2008 & qu==4) | (region=="NG" & year==2009 & qu==1) 
replace isbubbly=1 if  (region=="NN" & year==1999 & qu==2) | (region=="NN" & year==1999 & qu==3) | (region=="NN" & year==1999 & qu==4) | (region=="NN" & year==2000 & qu==1) | (region=="NN" & year==2000 & qu==2) | (region=="NN" & year==2000 & qu==3) | (region=="NN" & year==2000 & qu==4) | (region=="NN" & year==2001 & qu==1) | (region=="NN" & year==2001 & qu==2) | (region=="NN" & year==2001 & qu==3) | (region=="NN" & year==2001 & qu==4) | (region=="NN" & year==2002 & qu==1) | (region=="NN" & year==2002 & qu==2) | (region=="NN" & year==2002 & qu==3) | (region=="NN" & year==2002 & qu==4) | (region=="NN" & year==2003 & qu==1) | (region=="NN" & year==2003 & qu==2) | (region=="NN" & year==2003 & qu==3) | (region=="NN" & year==2003 & qu==4) | (region=="NN" & year==2004 & qu==1) | (region=="NN" & year==2004 & qu==2) | (region=="NN" & year==2004 & qu==3) | (region=="NN" & year==2004 & qu==4) | (region=="NN" & year==2005 & qu==1) 
replace isbubbly=1 if  (region=="NP" & year==2001 & qu==1) | (region=="NP" & year==2001 & qu==2) | (region=="NP" & year==2001 & qu==3) | (region=="NP" & year==2001 & qu==4) | (region=="NP" & year==2002 & qu==1) | (region=="NP" & year==2002 & qu==2) | (region=="NP" & year==2002 & qu==3) | (region=="NP" & year==2002 & qu==4) | (region=="NP" & year==2003 & qu==1) | (region=="NP" & year==2003 & qu==2) | (region=="NP" & year==2003 & qu==3) | (region=="NP" & year==2003 & qu==4) | (region=="NP" & year==2004 & qu==1) | (region=="NP" & year==2004 & qu==2) | (region=="NP" & year==2004 & qu==3) | (region=="NP" & year==2004 & qu==4) | (region=="NP" & year==2005 & qu==1) | (region=="NP" & year==2005 & qu==2) | (region=="NP" & year==2005 & qu==3) | (region=="NP" & year==2005 & qu==4) | (region=="NP" & year==2006 & qu==1) | (region=="NP" & year==2006 & qu==2) | (region=="NP" & year==2006 & qu==3) | (region=="NP" & year==2006 & qu==4) | (region=="NP" & year==2007 & qu==1) | (region=="NP" & year==2007 & qu==2) | (region=="NP" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="NR" & year==1999 & qu==1) | (region=="NR" & year==1999 & qu==2) | (region=="NR" & year==1999 & qu==3) | (region=="NR" & year==1999 & qu==4) | (region=="NR" & year==2000 & qu==1) | (region=="NR" & year==2000 & qu==2) | (region=="NR" & year==2000 & qu==3) | (region=="NR" & year==2000 & qu==4) | (region=="NR" & year==2001 & qu==1) | (region=="NR" & year==2001 & qu==2) | (region=="NR" & year==2001 & qu==3) | (region=="NR" & year==2001 & qu==4) | (region=="NR" & year==2002 & qu==1) | (region=="NR" & year==2002 & qu==2) | (region=="NR" & year==2002 & qu==3) | (region=="NR" & year==2002 & qu==4) | (region=="NR" & year==2003 & qu==1) | (region=="NR" & year==2003 & qu==2) | (region=="NR" & year==2003 & qu==3) | (region=="NR" & year==2003 & qu==4) | (region=="NR" & year==2004 & qu==1) | (region=="NR" & year==2004 & qu==2) | (region=="NR" & year==2004 & qu==3) | (region=="NR" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="NW" & year==1999 & qu==1) | (region=="NW" & year==1999 & qu==2) | (region=="NW" & year==1999 & qu==3) | (region=="NW" & year==1999 & qu==4) | (region=="NW" & year==2000 & qu==1) | (region=="NW" & year==2000 & qu==2) | (region=="NW" & year==2000 & qu==3) | (region=="NW" & year==2000 & qu==4) | (region=="NW" & year==2001 & qu==1) | (region=="NW" & year==2001 & qu==2) | (region=="NW" & year==2001 & qu==3) | (region=="NW" & year==2001 & qu==4) | (region=="NW" & year==2002 & qu==1) | (region=="NW" & year==2002 & qu==2) | (region=="NW" & year==2002 & qu==3) | (region=="NW" & year==2002 & qu==4) | (region=="NW" & year==2003 & qu==1) | (region=="NW" & year==2003 & qu==2) | (region=="NW" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="OL" & year==2000 & qu==3) | (region=="OL" & year==2000 & qu==4) | (region=="OL" & year==2001 & qu==2) | (region=="OL" & year==2001 & qu==3) | (region=="OL" & year==2001 & qu==4) | (region=="OL" & year==2002 & qu==1) | (region=="OL" & year==2002 & qu==2) | (region=="OL" & year==2002 & qu==3) | (region=="OL" & year==2002 & qu==4) | (region=="OL" & year==2003 & qu==1) | (region=="OL" & year==2003 & qu==2) | (region=="OL" & year==2003 & qu==3) | (region=="OL" & year==2003 & qu==4) | (region=="OL" & year==2004 & qu==1) | (region=="OL" & year==2004 & qu==2) | (region=="OL" & year==2004 & qu==3) | (region=="OL" & year==2004 & qu==4) | (region=="OL" & year==2005 & qu==1) | (region=="OL" & year==2005 & qu==2) | (region=="OL" & year==2005 & qu==3) | (region=="OL" & year==2005 & qu==4) | (region=="OL" & year==2006 & qu==1) | (region=="OL" & year==2006 & qu==2) | (region=="OL" & year==2006 & qu==3) | (region=="OL" & year==2006 & qu==4) | (region=="OL" & year==2007 & qu==1) | (region=="OL" & year==2007 & qu==2) | (region=="OL" & year==2007 & qu==3) | (region=="OL" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="OX" & year==1999 & qu==1) | (region=="OX" & year==1999 & qu==2) | (region=="OX" & year==1999 & qu==3) | (region=="OX" & year==1999 & qu==4) | (region=="OX" & year==2000 & qu==1) | (region=="OX" & year==2000 & qu==2) | (region=="OX" & year==2000 & qu==3) | (region=="OX" & year==2000 & qu==4) | (region=="OX" & year==2001 & qu==1) | (region=="OX" & year==2001 & qu==2) | (region=="OX" & year==2001 & qu==3) | (region=="OX" & year==2001 & qu==4) | (region=="OX" & year==2002 & qu==2) | (region=="OX" & year==2002 & qu==3) | (region=="OX" & year==2002 & qu==4) | (region=="OX" & year==2003 & qu==1) | (region=="OX" & year==2003 & qu==2) | (region=="OX" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="PE" & year==1999 & qu==1) | (region=="PE" & year==1999 & qu==2) | (region=="PE" & year==1999 & qu==3) | (region=="PE" & year==1999 & qu==4) | (region=="PE" & year==2000 & qu==1) | (region=="PE" & year==2000 & qu==2) | (region=="PE" & year==2000 & qu==3) | (region=="PE" & year==2000 & qu==4) | (region=="PE" & year==2001 & qu==1) | (region=="PE" & year==2001 & qu==2) | (region=="PE" & year==2001 & qu==3) | (region=="PE" & year==2001 & qu==4) | (region=="PE" & year==2002 & qu==1) | (region=="PE" & year==2002 & qu==2) | (region=="PE" & year==2002 & qu==3) | (region=="PE" & year==2002 & qu==4) | (region=="PE" & year==2003 & qu==1) | (region=="PE" & year==2003 & qu==2) | (region=="PE" & year==2003 & qu==3) | (region=="PE" & year==2003 & qu==4) | (region=="PE" & year==2004 & qu==1) | (region=="PE" & year==2004 & qu==2) | (region=="PE" & year==2004 & qu==3) | (region=="PE" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="PL" & year==1999 & qu==2) | (region=="PL" & year==1999 & qu==3) | (region=="PL" & year==1999 & qu==4) | (region=="PL" & year==2000 & qu==1) | (region=="PL" & year==2000 & qu==2) | (region=="PL" & year==2000 & qu==3) | (region=="PL" & year==2000 & qu==4) | (region=="PL" & year==2001 & qu==1) | (region=="PL" & year==2001 & qu==2) | (region=="PL" & year==2001 & qu==3) | (region=="PL" & year==2001 & qu==4) | (region=="PL" & year==2002 & qu==1) | (region=="PL" & year==2002 & qu==2) | (region=="PL" & year==2002 & qu==3) | (region=="PL" & year==2002 & qu==4) | (region=="PL" & year==2003 & qu==1) | (region=="PL" & year==2003 & qu==2) | (region=="PL" & year==2003 & qu==3) | (region=="PL" & year==2003 & qu==4) | (region=="PL" & year==2004 & qu==1) | (region=="PL" & year==2004 & qu==2) | (region=="PL" & year==2004 & qu==3) | (region=="PL" & year==2004 & qu==4) | (region=="PL" & year==2005 & qu==1) | (region=="PL" & year==2005 & qu==2) | (region=="PL" & year==2005 & qu==3) 
replace isbubbly=1 if  (region=="PO" & year==1999 & qu==1) | (region=="PO" & year==1999 & qu==2) | (region=="PO" & year==1999 & qu==3) | (region=="PO" & year==1999 & qu==4) | (region=="PO" & year==2000 & qu==1) | (region=="PO" & year==2000 & qu==2) | (region=="PO" & year==2000 & qu==3) | (region=="PO" & year==2000 & qu==4) | (region=="PO" & year==2001 & qu==1) | (region=="PO" & year==2001 & qu==2) | (region=="PO" & year==2001 & qu==3) | (region=="PO" & year==2001 & qu==4) | (region=="PO" & year==2002 & qu==1) | (region=="PO" & year==2002 & qu==2) | (region=="PO" & year==2002 & qu==3) | (region=="PO" & year==2002 & qu==4) | (region=="PO" & year==2003 & qu==1) | (region=="PO" & year==2003 & qu==2) | (region=="PO" & year==2003 & qu==3) | (region=="PO" & year==2003 & qu==4) | (region=="PO" & year==2004 & qu==1) | (region=="PO" & year==2004 & qu==2) | (region=="PO" & year==2004 & qu==3) | (region=="PO" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="PR" & year==2000 & qu==2) | (region=="PR" & year==2000 & qu==3) | (region=="PR" & year==2000 & qu==4) | (region=="PR" & year==2001 & qu==1) | (region=="PR" & year==2001 & qu==2) | (region=="PR" & year==2001 & qu==3) | (region=="PR" & year==2001 & qu==4) | (region=="PR" & year==2002 & qu==1) | (region=="PR" & year==2002 & qu==2) | (region=="PR" & year==2002 & qu==3) | (region=="PR" & year==2002 & qu==4) | (region=="PR" & year==2003 & qu==1) | (region=="PR" & year==2003 & qu==2) | (region=="PR" & year==2003 & qu==3) | (region=="PR" & year==2003 & qu==4) | (region=="PR" & year==2004 & qu==1) | (region=="PR" & year==2004 & qu==2) | (region=="PR" & year==2004 & qu==3) | (region=="PR" & year==2004 & qu==4) | (region=="PR" & year==2005 & qu==1) | (region=="PR" & year==2005 & qu==2) | (region=="PR" & year==2005 & qu==3) | (region=="PR" & year==2005 & qu==4) | (region=="PR" & year==2006 & qu==1) | (region=="PR" & year==2006 & qu==2) | (region=="PR" & year==2006 & qu==3) | (region=="PR" & year==2006 & qu==4) | (region=="PR" & year==2007 & qu==1) | (region=="PR" & year==2007 & qu==2) | (region=="PR" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="RG" & year==1999 & qu==3) | (region=="RG" & year==1999 & qu==4) | (region=="RG" & year==2000 & qu==1) | (region=="RG" & year==2000 & qu==2) | (region=="RG" & year==2000 & qu==3) 
replace isbubbly=1 if  (region=="RH" & year==1999 & qu==1) | (region=="RH" & year==1999 & qu==2) | (region=="RH" & year==1999 & qu==3) | (region=="RH" & year==1999 & qu==4) | (region=="RH" & year==2000 & qu==1) | (region=="RH" & year==2000 & qu==2) | (region=="RH" & year==2000 & qu==3) | (region=="RH" & year==2000 & qu==4) | (region=="RH" & year==2001 & qu==1) | (region=="RH" & year==2001 & qu==2) | (region=="RH" & year==2001 & qu==3) | (region=="RH" & year==2001 & qu==4) | (region=="RH" & year==2002 & qu==2) | (region=="RH" & year==2002 & qu==3) | (region=="RH" & year==2002 & qu==4) | (region=="RH" & year==2003 & qu==1) | (region=="RH" & year==2003 & qu==2) | (region=="RH" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="RM" & year==1999 & qu==1) | (region=="RM" & year==1999 & qu==2) | (region=="RM" & year==1999 & qu==3) | (region=="RM" & year==1999 & qu==4) | (region=="RM" & year==2000 & qu==1) | (region=="RM" & year==2000 & qu==2) | (region=="RM" & year==2000 & qu==3) | (region=="RM" & year==2000 & qu==4) | (region=="RM" & year==2001 & qu==1) | (region=="RM" & year==2001 & qu==2) | (region=="RM" & year==2001 & qu==3) | (region=="RM" & year==2001 & qu==4) | (region=="RM" & year==2002 & qu==1) | (region=="RM" & year==2002 & qu==2) | (region=="RM" & year==2002 & qu==3) | (region=="RM" & year==2002 & qu==4) | (region=="RM" & year==2003 & qu==1) | (region=="RM" & year==2003 & qu==2) | (region=="RM" & year==2003 & qu==3) | (region=="RM" & year==2003 & qu==4) | (region=="RM" & year==2004 & qu==1) | (region=="RM" & year==2004 & qu==2) | (region=="RM" & year==2004 & qu==3) | (region=="RM" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="S"  & year==2000 & qu==2) | (region=="S"  & year==2000 & qu==3) | (region=="S"  & year==2000 & qu==4) | (region=="S"  & year==2001 & qu==1) | (region=="S"  & year==2001 & qu==2) | (region=="S"  & year==2001 & qu==3) | (region=="S" & year==2001 & qu==4) | (region=="S" & year==2002 & qu==1) | (region=="S" & year==2002 & qu==2) | (region=="S" & year==2002 & qu==3) | (region=="S" & year==2002 & qu==4) | (region=="S" & year==2003 & qu==1) | (region=="S" & year==2003 & qu==2) | (region=="S" & year==2003 & qu==3) | (region=="S" & year==2003 & qu==4) | (region=="S" & year==2004 & qu==1) | (region=="S" & year==2004 & qu==2) | (region=="S" & year==2004 & qu==3) | (region=="S" & year==2004 & qu==4) | (region=="S" & year==2005 & qu==1) | (region=="S" & year==2005 & qu==2) | (region=="S" & year==2005 & qu==3) | (region=="S" & year==2005 & qu==4) | (region=="S" & year==2006 & qu==1) | (region=="S" & year==2006 & qu==2) | (region=="S" & year==2006 & qu==3) | (region=="S" & year==2006 & qu==4) 
replace isbubbly=1 if  (region=="SA" & year==2000 & qu==2) | (region=="SA" & year==2000 & qu==3) | (region=="SA" & year==2001 & qu==1) | (region=="SA" & year==2001 & qu==2) | (region=="SA" & year==2001 & qu==3) | (region=="SA" & year==2001 & qu==4) | (region=="SA" & year==2002 & qu==1) | (region=="SA" & year==2002 & qu==2) | (region=="SA" & year==2002 & qu==3) | (region=="SA" & year==2002 & qu==4) | (region=="SA" & year==2003 & qu==1) | (region=="SA" & year==2003 & qu==2) | (region=="SA" & year==2003 & qu==3) | (region=="SA" & year==2003 & qu==4) | (region=="SA" & year==2004 & qu==1) | (region=="SA" & year==2004 & qu==2) | (region=="SA" & year==2004 & qu==3) | (region=="SA" & year==2004 & qu==4) | (region=="SA" & year==2005 & qu==1) | (region=="SA" & year==2005 & qu==2) | (region=="SA" & year==2005 & qu==3) | (region=="SA" & year==2005 & qu==4) | (region=="SA" & year==2006 & qu==1) | (region=="SA" & year==2006 & qu==2) | (region=="SA" & year==2006 & qu==3) | (region=="SA" & year==2006 & qu==4) | (region=="SA" & year==2007 & qu==1) 
replace isbubbly=1 if  (region=="SE" & year==1999 & qu==2) | (region=="SE" & year==1999 & qu==3) | (region=="SE" & year==1999 & qu==4) | (region=="SE" & year==2000 & qu==1) | (region=="SE" & year==2000 & qu==2) | (region=="SE" & year==2000 & qu==3) | (region=="SE" & year==2000 & qu==4) | (region=="SE" & year==2001 & qu==1) | (region=="SE" & year==2001 & qu==3) | (region=="SE" & year==2001 & qu==4) | (region=="SE" & year==2002 & qu==1) | (region=="SE" & year==2002 & qu==2) | (region=="SE" & year==2002 & qu==3) | (region=="SE" & year==2002 & qu==4) | (region=="SE" & year==2003 & qu==1) | (region=="SE" & year==2003 & qu==2) | (region=="SE" & year==2007 & qu==2) | (region=="SE" & year==2007 & qu==3) | (region=="SE" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="SG" & year==1999 & qu==2) | (region=="SG" & year==1999 & qu==3) | (region=="SG" & year==1999 & qu==4) | (region=="SG" & year==2000 & qu==1) | (region=="SG" & year==2000 & qu==2) | (region=="SG" & year==2000 & qu==3) | (region=="SG" & year==2000 & qu==4) | (region=="SG" & year==2001 & qu==2) | (region=="SG" & year==2001 & qu==3) | (region=="SG" & year==2001 & qu==4) | (region=="SG" & year==2002 & qu==2) | (region=="SG" & year==2002 & qu==3) | (region=="SG" & year==2002 & qu==4) | (region=="SG" & year==2003 & qu==1) | (region=="SG" & year==2003 & qu==2) | (region=="SG" & year==2003 & qu==3) 
replace isbubbly=1 if  (region=="SK" & year==1999 & qu==1) | (region=="SK" & year==1999 & qu==2) | (region=="SK" & year==1999 & qu==3) | (region=="SK" & year==1999 & qu==4) | (region=="SK" & year==2000 & qu==1) | (region=="SK" & year==2000 & qu==2) | (region=="SK" & year==2000 & qu==3) | (region=="SK" & year==2000 & qu==4) | (region=="SK" & year==2001 & qu==1) | (region=="SK" & year==2001 & qu==2) | (region=="SK" & year==2001 & qu==3) | (region=="SK" & year==2001 & qu==4) | (region=="SK" & year==2002 & qu==1) | (region=="SK" & year==2002 & qu==2) | (region=="SK" & year==2002 & qu==3) | (region=="SK" & year==2002 & qu==4) | (region=="SK" & year==2003 & qu==1) | (region=="SK" & year==2003 & qu==2) | (region=="SK" & year==2003 & qu==3) | (region=="SK" & year==2003 & qu==4) | (region=="SK" & year==2004 & qu==1) | (region=="SK" & year==2004 & qu==2) | (region=="SK" & year==2004 & qu==3) | (region=="SK" & year==2004 & qu==4) | (region=="SK" & year==2005 & qu==1) | (region=="SK" & year==2005 & qu==2) | (region=="SK" & year==2005 & qu==3) | (region=="SK" & year==2005 & qu==4) | (region=="SK" & year==2006 & qu==1) | (region=="SK" & year==2006 & qu==2) | (region=="SK" & year==2006 & qu==3) 
replace isbubbly=1 if  (region=="SL" & year==1999 & qu==1) | (region=="SL" & year==1999 & qu==2) | (region=="SL" & year==1999 & qu==3) | (region=="SL" & year==1999 & qu==4) | (region=="SL" & year==2000 & qu==1) | (region=="SL" & year==2000 & qu==2) | (region=="SL" & year==2000 & qu==3) | (region=="SL" & year==2000 & qu==4) | (region=="SL" & year==2001 & qu==1) | (region=="SL" & year==2001 & qu==2) | (region=="SL" & year==2001 & qu==3) | (region=="SL" & year==2001 & qu==4) | (region=="SL" & year==2002 & qu==1) | (region=="SL" & year==2002 & qu==2) | (region=="SL" & year==2002 & qu==3) | (region=="SL" & year==2002 & qu==4) | (region=="SL" & year==2003 & qu==1) | (region=="SL" & year==2003 & qu==2) | (region=="SL" & year==2007 & qu==3) | (region=="SL" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="SM" & year==1999 & qu==1) | (region=="SM" & year==1999 & qu==2) | (region=="SM" & year==1999 & qu==3) | (region=="SM" & year==1999 & qu==4) | (region=="SM" & year==2000 & qu==1) | (region=="SM" & year==2000 & qu==2) | (region=="SM" & year==2000 & qu==3) 
replace isbubbly=1 if  (region=="SN" & year==1999 & qu==1) | (region=="SN" & year==1999 & qu==2) | (region=="SN" & year==1999 & qu==3) | (region=="SN" & year==1999 & qu==4) | (region=="SN" & year==2000 & qu==1) | (region=="SN" & year==2000 & qu==2) | (region=="SN" & year==2000 & qu==3) | (region=="SN" & year==2001 & qu==1) | (region=="SN" & year==2001 & qu==2) | (region=="SN" & year==2001 & qu==3) | (region=="SN" & year==2001 & qu==4) | (region=="SN" & year==2002 & qu==2) | (region=="SN" & year==2002 & qu==3) | (region=="SN" & year==2002 & qu==4) | (region=="SN" & year==2003 & qu==1) | (region=="SN" & year==2003 & qu==2) | (region=="SN" & year==2003 & qu==3) | (region=="SN" & year==2004 & qu==2) | (region=="SN" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="SO" & year==1999 & qu==1) | (region=="SO" & year==1999 & qu==2) | (region=="SO" & year==1999 & qu==3) | (region=="SO" & year==1999 & qu==4) | (region=="SO" & year==2000 & qu==1) | (region=="SO" & year==2000 & qu==2) | (region=="SO" & year==2000 & qu==3) | (region=="SO" & year==2000 & qu==4) | (region=="SO" & year==2001 & qu==1) | (region=="SO" & year==2001 & qu==2) | (region=="SO" & year==2001 & qu==3) | (region=="SO" & year==2001 & qu==4) | (region=="SO" & year==2002 & qu==1) | (region=="SO" & year==2002 & qu==2) | (region=="SO" & year==2002 & qu==3) | (region=="SO" & year==2002 & qu==4) | (region=="SO" & year==2003 & qu==1) | (region=="SO" & year==2003 & qu==2) | (region=="SO" & year==2003 & qu==3) | (region=="SO" & year==2004 & qu==1) | (region=="SO" & year==2004 & qu==2) | (region=="SO" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="SP" & year==1999 & qu==1) | (region=="SP" & year==1999 & qu==2) | (region=="SP" & year==1999 & qu==3) | (region=="SP" & year==1999 & qu==4) | (region=="SP" & year==2000 & qu==1) | (region=="SP" & year==2000 & qu==2) | (region=="SP" & year==2000 & qu==3) | (region=="SP" & year==2000 & qu==4) | (region=="SP" & year==2001 & qu==1) | (region=="SP" & year==2001 & qu==2) | (region=="SP" & year==2001 & qu==3) | (region=="SP" & year==2001 & qu==4) | (region=="SP" & year==2002 & qu==1) | (region=="SP" & year==2002 & qu==2) | (region=="SP" & year==2002 & qu==3) | (region=="SP" & year==2002 & qu==4) | (region=="SP" & year==2003 & qu==1) | (region=="SP" & year==2003 & qu==2) | (region=="SP" & year==2003 & qu==3) | (region=="SP" & year==2003 & qu==4) | (region=="SP" & year==2004 & qu==1) | (region=="SP" & year==2004 & qu==2) | (region=="SP" & year==2004 & qu==3) | (region=="SP" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="SR" & year==2002 & qu==2) | (region=="SR" & year==2002 & qu==3) | (region=="SR" & year==2002 & qu==4) | (region=="SR" & year==2003 & qu==1) | (region=="SR" & year==2003 & qu==2) | (region=="SR" & year==2003 & qu==3) | (region=="SR" & year==2003 & qu==4) | (region=="SR" & year==2004 & qu==1) | (region=="SR" & year==2004 & qu==2) | (region=="SR" & year==2004 & qu==3) | (region=="SR" & year==2004 & qu==4) | (region=="SR" & year==2005 & qu==1) | (region=="SR" & year==2005 & qu==2) | (region=="SR" & year==2005 & qu==3) | (region=="SR" & year==2005 & qu==4) | (region=="SR" & year==2006 & qu==1) | (region=="SR" & year==2006 & qu==2) | (region=="SR" & year==2006 & qu==3) | (region=="SR" & year==2006 & qu==4) | (region=="SR" & year==2007 & qu==1) | (region=="SR" & year==2007 & qu==2) | (region=="SR" & year==2007 & qu==3) | (region=="SR" & year==2007 & qu==4) | (region=="SR" & year==2008 & qu==1) | (region=="SR" & year==2008 & qu==2) 
replace isbubbly=1 if  (region=="SS" & year==1999 & qu==2) | (region=="SS" & year==1999 & qu==3) | (region=="SS" & year==1999 & qu==4) | (region=="SS" & year==2000 & qu==1) | (region=="SS" & year==2000 & qu==2) | (region=="SS" & year==2000 & qu==3) | (region=="SS" & year==2000 & qu==4) | (region=="SS" & year==2001 & qu==1) | (region=="SS" & year==2001 & qu==2) | (region=="SS" & year==2001 & qu==3) | (region=="SS" & year==2001 & qu==4) | (region=="SS" & year==2002 & qu==1) | (region=="SS" & year==2002 & qu==2) | (region=="SS" & year==2002 & qu==3) | (region=="SS" & year==2002 & qu==4) | (region=="SS" & year==2003 & qu==1) | (region=="SS" & year==2003 & qu==2) | (region=="SS" & year==2003 & qu==3) | (region=="SS" & year==2003 & qu==4) | (region=="SS" & year==2004 & qu==1) | (region=="SS" & year==2004 & qu==2) | (region=="SS" & year==2004 & qu==3) | (region=="SS" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="ST" & year==2000 & qu==2) | (region=="ST" & year==2000 & qu==3) | (region=="ST" & year==2000 & qu==4) | (region=="ST" & year==2001 & qu==1) | (region=="ST" & year==2001 & qu==2) | (region=="ST" & year==2001 & qu==3) | (region=="ST" & year==2001 & qu==4) | (region=="ST" & year==2002 & qu==1) | (region=="ST" & year==2002 & qu==2) | (region=="ST" & year==2002 & qu==3) | (region=="ST" & year==2002 & qu==4) | (region=="ST" & year==2003 & qu==1) | (region=="ST" & year==2003 & qu==2) | (region=="ST" & year==2003 & qu==3) | (region=="ST" & year==2003 & qu==4) | (region=="ST" & year==2004 & qu==1) | (region=="ST" & year==2004 & qu==2) | (region=="ST" & year==2004 & qu==3) | (region=="ST" & year==2004 & qu==4) | (region=="ST" & year==2005 & qu==1) | (region=="ST" & year==2005 & qu==2) | (region=="ST" & year==2005 & qu==3) | (region=="ST" & year==2005 & qu==4) | (region=="ST" & year==2006 & qu==1) | (region=="ST" & year==2006 & qu==2) | (region=="ST" & year==2006 & qu==3) | (region=="ST" & year==2006 & qu==4) | (region=="ST" & year==2007 & qu==2) | (region=="ST" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="SW" & year==1999 & qu==3) | (region=="SW" & year==1999 & qu==4) | (region=="SW" & year==2000 & qu==1) | (region=="SW" & year==2000 & qu==2) | (region=="SW" & year==2000 & qu==3) | (region=="SW" & year==2007 & qu==1) | (region=="SW" & year==2007 & qu==2) | (region=="SW" & year==2007 & qu==3) | (region=="SW" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="SY" & year==2000 & qu==2) | (region=="SY" & year==2000 & qu==3) | (region=="SY" & year==2000 & qu==4) | (region=="SY" & year==2001 & qu==1) | (region=="SY" & year==2001 & qu==2) | (region=="SY" & year==2001 & qu==3) | (region=="SY" & year==2001 & qu==4) | (region=="SY" & year==2002 & qu==1) | (region=="SY" & year==2002 & qu==2) | (region=="SY" & year==2002 & qu==3) | (region=="SY" & year==2002 & qu==4) | (region=="SY" & year==2003 & qu==1) | (region=="SY" & year==2003 & qu==2) | (region=="SY" & year==2003 & qu==3) | (region=="SY" & year==2003 & qu==4) | (region=="SY" & year==2004 & qu==1) | (region=="SY" & year==2004 & qu==2) | (region=="SY" & year==2004 & qu==3) | (region=="SY" & year==2004 & qu==4) | (region=="SY" & year==2005 & qu==1) | (region=="SY" & year==2005 & qu==2) | (region=="SY" & year==2005 & qu==3) | (region=="SY" & year==2005 & qu==4) | (region=="SY" & year==2006 & qu==1) | (region=="SY" & year==2006 & qu==2) | (region=="SY" & year==2006 & qu==3) | (region=="SY" & year==2006 & qu==4) | (region=="SY" & year==2007 & qu==1) | (region=="SY" & year==2007 & qu==2) | (region=="SY" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="TA" & year==1999 & qu==2) | (region=="TA" & year==1999 & qu==3) | (region=="TA" & year==1999 & qu==4) | (region=="TA" & year==2000 & qu==1) | (region=="TA" & year==2000 & qu==2) | (region=="TA" & year==2000 & qu==3) | (region=="TA" & year==2000 & qu==4) | (region=="TA" & year==2001 & qu==1) | (region=="TA" & year==2001 & qu==2) | (region=="TA" & year==2001 & qu==3) | (region=="TA" & year==2001 & qu==4) | (region=="TA" & year==2002 & qu==1) | (region=="TA" & year==2002 & qu==2) | (region=="TA" & year==2002 & qu==3) | (region=="TA" & year==2002 & qu==4) | (region=="TA" & year==2003 & qu==1) | (region=="TA" & year==2003 & qu==2) | (region=="TA" & year==2003 & qu==3) | (region=="TA" & year==2003 & qu==4) | (region=="TA" & year==2004 & qu==1) | (region=="TA" & year==2004 & qu==2) | (region=="TA" & year==2004 & qu==3) | (region=="TA" & year==2004 & qu==4) | (region=="TA" & year==2005 & qu==1) | (region=="TA" & year==2005 & qu==2) 
replace isbubbly=1 if  (region=="TF" & year==1999 & qu==1) | (region=="TF" & year==1999 & qu==2) | (region=="TF" & year==1999 & qu==3) | (region=="TF" & year==1999 & qu==4) | (region=="TF" & year==2000 & qu==1) | (region=="TF" & year==2000 & qu==2) | (region=="TF" & year==2000 & qu==3) | (region=="TF" & year==2000 & qu==4) | (region=="TF" & year==2001 & qu==1) | (region=="TF" & year==2001 & qu==2) | (region=="TF" & year==2001 & qu==3) | (region=="TF" & year==2001 & qu==4) | (region=="TF" & year==2002 & qu==1) | (region=="TF" & year==2002 & qu==2) | (region=="TF" & year==2002 & qu==3) | (region=="TF" & year==2002 & qu==4) | (region=="TF" & year==2003 & qu==1) | (region=="TF" & year==2003 & qu==2) | (region=="TF" & year==2003 & qu==3) | (region=="TF" & year==2003 & qu==4) | (region=="TF" & year==2004 & qu==1) | (region=="TF" & year==2004 & qu==2) | (region=="TF" & year==2004 & qu==3) | (region=="TF" & year==2004 & qu==4) | (region=="TF" & year==2005 & qu==1) | (region=="TF" & year==2005 & qu==2) | (region=="TF" & year==2005 & qu==3) | (region=="TF" & year==2005 & qu==4) | (region=="TF" & year==2006 & qu==1) | (region=="TF" & year==2006 & qu==2) | (region=="TF" & year==2006 & qu==3) | (region=="TF" & year==2006 & qu==4) | (region=="TF" & year==2007 & qu==1) 
replace isbubbly=1 if  (region=="TN" & year==1999 & qu==3) | (region=="TN" & year==1999 & qu==4) | (region=="TN" & year==2000 & qu==1) | (region=="TN" & year==2000 & qu==2) | (region=="TN" & year==2000 & qu==3) | (region=="TN" & year==2001 & qu==1) | (region=="TN" & year==2001 & qu==2) | (region=="TN" & year==2001 & qu==3) | (region=="TN" & year==2001 & qu==4) | (region=="TN" & year==2002 & qu==1) | (region=="TN" & year==2002 & qu==2) | (region=="TN" & year==2002 & qu==3) | (region=="TN" & year==2002 & qu==4) | (region=="TN" & year==2003 & qu==1) | (region=="TN" & year==2003 & qu==2) | (region=="TN" & year==2003 & qu==3) | (region=="TN" & year==2003 & qu==4) | (region=="TN" & year==2004 & qu==2) | (region=="TN" & year==2004 & qu==3) 
replace isbubbly=1 if  (region=="TQ" & year==1999 & qu==2) | (region=="TQ" & year==1999 & qu==3) | (region=="TQ" & year==1999 & qu==4) | (region=="TQ" & year==2000 & qu==1) | (region=="TQ" & year==2000 & qu==2) | (region=="TQ" & year==2000 & qu==3) | (region=="TQ" & year==2000 & qu==4) | (region=="TQ" & year==2001 & qu==1) | (region=="TQ" & year==2001 & qu==2) | (region=="TQ" & year==2001 & qu==3) | (region=="TQ" & year==2001 & qu==4) | (region=="TQ" & year==2002 & qu==1) | (region=="TQ" & year==2002 & qu==2) | (region=="TQ" & year==2002 & qu==3) | (region=="TQ" & year==2002 & qu==4) | (region=="TQ" & year==2003 & qu==1) | (region=="TQ" & year==2003 & qu==2) | (region=="TQ" & year==2003 & qu==3) | (region=="TQ" & year==2003 & qu==4) | (region=="TQ" & year==2004 & qu==1) | (region=="TQ" & year==2004 & qu==2) | (region=="TQ" & year==2004 & qu==3) | (region=="TQ" & year==2004 & qu==4) | (region=="TQ" & year==2005 & qu==1) 
replace isbubbly=1 if  (region=="TR" & year==1999 & qu==3) | (region=="TR" & year==1999 & qu==4) | (region=="TR" & year==2000 & qu==1) | (region=="TR" & year==2000 & qu==2) | (region=="TR" & year==2000 & qu==3) | (region=="TR" & year==2000 & qu==4) | (region=="TR" & year==2001 & qu==1) | (region=="TR" & year==2001 & qu==2) | (region=="TR" & year==2001 & qu==3) | (region=="TR" & year==2001 & qu==4) | (region=="TR" & year==2002 & qu==1) | (region=="TR" & year==2002 & qu==2) | (region=="TR" & year==2002 & qu==3) | (region=="TR" & year==2002 & qu==4) | (region=="TR" & year==2003 & qu==1) | (region=="TR" & year==2003 & qu==2) | (region=="TR" & year==2003 & qu==3) | (region=="TR" & year==2003 & qu==4) | (region=="TR" & year==2004 & qu==1) | (region=="TR" & year==2004 & qu==2) | (region=="TR" & year==2004 & qu==3) | (region=="TR" & year==2004 & qu==4) 
replace isbubbly=1 if  (region=="TS" & year==2001 & qu==2) | (region=="TS" & year==2001 & qu==3) | (region=="TS" & year==2001 & qu==4) | (region=="TS" & year==2002 & qu==1) | (region=="TS" & year==2002 & qu==2) | (region=="TS" & year==2002 & qu==3) | (region=="TS" & year==2002 & qu==4) | (region=="TS" & year==2003 & qu==1) | (region=="TS" & year==2003 & qu==2) | (region=="TS" & year==2003 & qu==3) | (region=="TS" & year==2003 & qu==4) | (region=="TS" & year==2004 & qu==1) | (region=="TS" & year==2004 & qu==2) | (region=="TS" & year==2004 & qu==3) | (region=="TS" & year==2004 & qu==4) | (region=="TS" & year==2005 & qu==1) | (region=="TS" & year==2005 & qu==2) | (region=="TS" & year==2005 & qu==3) | (region=="TS" & year==2005 & qu==4) | (region=="TS" & year==2006 & qu==1) | (region=="TS" & year==2006 & qu==2) | (region=="TS" & year==2006 & qu==3) | (region=="TS" & year==2006 & qu==4) | (region=="TS" & year==2007 & qu==1) | (region=="TS" & year==2007 & qu==2) | (region=="TS" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="TW" & year==1999 & qu==1) | (region=="TW" & year==1999 & qu==2) | (region=="TW" & year==1999 & qu==3) | (region=="TW" & year==1999 & qu==4) | (region=="TW" & year==2000 & qu==1) | (region=="TW" & year==2000 & qu==2) | (region=="TW" & year==2000 & qu==3) | (region=="TW" & year==2007 & qu==3) | (region=="TW" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="UB" & year==1999 & qu==1) | (region=="UB" & year==1999 & qu==2) | (region=="UB" & year==1999 & qu==3) | (region=="UB" & year==1999 & qu==4) | (region=="UB" & year==2000 & qu==1) | (region=="UB" & year==2000 & qu==2) | (region=="UB" & year==2000 & qu==3) | (region=="UB" & year==2000 & qu==4) | (region=="UB" & year==2001 & qu==1) | (region=="UB" & year==2001 & qu==2) | (region=="UB" & year==2001 & qu==3) | (region=="UB" & year==2001 & qu==4) | (region=="UB" & year==2002 & qu==1) | (region=="UB" & year==2002 & qu==2) | (region=="UB" & year==2002 & qu==3) | (region=="UB" & year==2002 & qu==4) | (region=="UB" & year==2003 & qu==1) | (region=="UB" & year==2003 & qu==2) | (region=="UB" & year==2003 & qu==3) | (region=="UB" & year==2003 & qu==4) | (region=="UB" & year==2007 & qu==3) | (region=="UB" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="W"  & year==1999 & qu==3) | (region=="W"  & year==1999 & qu==4) | (region=="W"  & year==2000 & qu==1) | (region=="W"  & year==2000 & qu==2) | (region=="W"  & year==2000 & qu==3) | (region=="W"  & year==2000 & qu==4) | (region=="W" & year==2007 & qu==1) | (region=="W" & year==2007 & qu==2) | (region=="W" & year==2007 & qu==3) | (region=="W" & year==2007 & qu==4) | (region=="W" & year==2008 & qu==1) 
replace isbubbly=1 if  (region=="WA" & year==1999 & qu==3) | (region=="WA" & year==1999 & qu==4) | (region=="WA" & year==2000 & qu==1) | (region=="WA" & year==2000 & qu==2) | (region=="WA" & year==2000 & qu==3) | (region=="WA" & year==2000 & qu==4) | (region=="WA" & year==2001 & qu==1) | (region=="WA" & year==2001 & qu==2) | (region=="WA" & year==2001 & qu==3) | (region=="WA" & year==2001 & qu==4) | (region=="WA" & year==2002 & qu==1) | (region=="WA" & year==2002 & qu==2) | (region=="WA" & year==2002 & qu==3) | (region=="WA" & year==2002 & qu==4) | (region=="WA" & year==2003 & qu==1) | (region=="WA" & year==2003 & qu==2) | (region=="WA" & year==2003 & qu==3) | (region=="WA" & year==2003 & qu==4) | (region=="WA" & year==2004 & qu==1) | (region=="WA" & year==2004 & qu==2) | (region=="WA" & year==2004 & qu==3) | (region=="WA" & year==2004 & qu==4) | (region=="WA" & year==2005 & qu==1) | (region=="WA" & year==2005 & qu==2) | (region=="WA" & year==2005 & qu==3) | (region=="WA" & year==2005 & qu==4) | (region=="WA" & year==2006 & qu==1) | (region=="WA" & year==2006 & qu==2) | (region=="WA" & year==2006 & qu==3) | (region=="WA" & year==2006 & qu==4) 
replace isbubbly=1 if  (region=="WD" & year==1999 & qu==3) | (region=="WD" & year==1999 & qu==4) | (region=="WD" & year==2000 & qu==1) | (region=="WD" & year==2000 & qu==2) | (region=="WD" & year==2000 & qu==3) | (region=="WD" & year==2002 & qu==3) | (region=="WD" & year==2002 & qu==4) | (region=="WD" & year==2003 & qu==1) | (region=="WD" & year==2003 & qu==2) 
replace isbubbly=1 if  (region=="WF" & year==2000 & qu==2) | (region=="WF" & year==2000 & qu==3) | (region=="WF" & year==2000 & qu==4) | (region=="WF" & year==2001 & qu==1) | (region=="WF" & year==2001 & qu==2) | (region=="WF" & year==2001 & qu==3) | (region=="WF" & year==2001 & qu==4) | (region=="WF" & year==2002 & qu==1) | (region=="WF" & year==2002 & qu==2) | (region=="WF" & year==2002 & qu==3) | (region=="WF" & year==2002 & qu==4) | (region=="WF" & year==2003 & qu==1) | (region=="WF" & year==2003 & qu==2) | (region=="WF" & year==2003 & qu==3) | (region=="WF" & year==2003 & qu==4) | (region=="WF" & year==2004 & qu==1) | (region=="WF" & year==2004 & qu==2) | (region=="WF" & year==2004 & qu==3) | (region=="WF" & year==2004 & qu==4) | (region=="WF" & year==2005 & qu==1) | (region=="WF" & year==2005 & qu==2) | (region=="WF" & year==2005 & qu==3) | (region=="WF" & year==2005 & qu==4) | (region=="WF" & year==2006 & qu==1) | (region=="WF" & year==2006 & qu==2) | (region=="WF" & year==2006 & qu==3) | (region=="WF" & year==2006 & qu==4) | (region=="WF" & year==2007 & qu==1) | (region=="WF" & year==2007 & qu==2) | (region=="WF" & year==2007 & qu==3) 
replace isbubbly=1 if  (region=="WN" & year==2002 & qu==1) | (region=="WN" & year==2002 & qu==2) | (region=="WN" & year==2002 & qu==3) | (region=="WN" & year==2002 & qu==4) | (region=="WN" & year==2003 & qu==1) | (region=="WN" & year==2003 & qu==2) | (region=="WN" & year==2003 & qu==3) | (region=="WN" & year==2003 & qu==4) | (region=="WN" & year==2004 & qu==1) | (region=="WN" & year==2004 & qu==2) | (region=="WN" & year==2004 & qu==3) | (region=="WN" & year==2004 & qu==4) | (region=="WN" & year==2005 & qu==1) | (region=="WN" & year==2005 & qu==2) | (region=="WN" & year==2005 & qu==3) | (region=="WN" & year==2005 & qu==4) | (region=="WN" & year==2006 & qu==1) | (region=="WN" & year==2006 & qu==2) | (region=="WN" & year==2006 & qu==3) | (region=="WN" & year==2006 & qu==4) | (region=="WN" & year==2007 & qu==1) | (region=="WN" & year==2007 & qu==2) | (region=="WN" & year==2007 & qu==3) | (region=="WN" & year==2007 & qu==4) | (region=="WN" & year==2008 & qu==1) | (region=="WN" & year==2008 & qu==2) 
replace isbubbly=1 if  (region=="WR" & year==1999 & qu==1) | (region=="WR" & year==1999 & qu==2) | (region=="WR" & year==1999 & qu==3) | (region=="WR" & year==1999 & qu==4) | (region=="WR" & year==2000 & qu==1) | (region=="WR" & year==2000 & qu==2) | (region=="WR" & year==2000 & qu==3) | (region=="WR" & year==2000 & qu==4) | (region=="WR" & year==2001 & qu==1) | (region=="WR" & year==2001 & qu==2) | (region=="WR" & year==2001 & qu==3) | (region=="WR" & year==2001 & qu==4) | (region=="WR" & year==2002 & qu==1) | (region=="WR" & year==2002 & qu==2) | (region=="WR" & year==2002 & qu==3) | (region=="WR" & year==2002 & qu==4) | (region=="WR" & year==2003 & qu==1) | (region=="WR" & year==2003 & qu==2) | (region=="WR" & year==2003 & qu==3) | (region=="WR" & year==2003 & qu==4) | (region=="WR" & year==2004 & qu==1) | (region=="WR" & year==2004 & qu==2) | (region=="WR" & year==2004 & qu==3) | (region=="WR" & year==2004 & qu==4) | (region=="WR" & year==2005 & qu==1) | (region=="WR" & year==2005 & qu==2) | (region=="WR" & year==2005 & qu==3) | (region=="WR" & year==2005 & qu==4) | (region=="WR" & year==2006 & qu==1) | (region=="WR" & year==2009 & qu==1) | (region=="WR" & year==2009 & qu==2) 
replace isbubbly=1 if  (region=="WS" & year==1999 & qu==2) | (region=="WS" & year==1999 & qu==3) | (region=="WS" & year==1999 & qu==4) | (region=="WS" & year==2000 & qu==1) | (region=="WS" & year==2000 & qu==2) | (region=="WS" & year==2000 & qu==3) | (region=="WS" & year==2000 & qu==4) | (region=="WS" & year==2001 & qu==1) | (region=="WS" & year==2001 & qu==2) | (region=="WS" & year==2001 & qu==3) | (region=="WS" & year==2001 & qu==4) | (region=="WS" & year==2002 & qu==1) | (region=="WS" & year==2002 & qu==2) | (region=="WS" & year==2002 & qu==3) | (region=="WS" & year==2002 & qu==4) | (region=="WS" & year==2003 & qu==1) | (region=="WS" & year==2003 & qu==2) | (region=="WS" & year==2003 & qu==3) | (region=="WS" & year==2003 & qu==4) | (region=="WS" & year==2004 & qu==1) | (region=="WS" & year==2004 & qu==2) | (region=="WS" & year==2004 & qu==3) | (region=="WS" & year==2004 & qu==4) | (region=="WS" & year==2005 & qu==1) | (region=="WS" & year==2005 & qu==2) | (region=="WS" & year==2005 & qu==3) | (region=="WS" & year==2005 & qu==4) | (region=="WS" & year==2006 & qu==1) | (region=="WS" & year==2006 & qu==2) | (region=="WS" & year==2006 & qu==3) | (region=="WS" & year==2006 & qu==4) | (region=="WS" & year==2007 & qu==1) 
replace isbubbly=1 if  (region=="WV" & year==2000 & qu==2) | (region=="WV" & year==2000 & qu==3) | (region=="WV" & year==2000 & qu==4) | (region=="WV" & year==2001 & qu==2) | (region=="WV" & year==2001 & qu==3) | (region=="WV" & year==2001 & qu==4) | (region=="WV" & year==2002 & qu==1) | (region=="WV" & year==2002 & qu==2) | (region=="WV" & year==2002 & qu==3) | (region=="WV" & year==2002 & qu==4) | (region=="WV" & year==2003 & qu==1) | (region=="WV" & year==2003 & qu==2) | (region=="WV" & year==2003 & qu==3) | (region=="WV" & year==2003 & qu==4) | (region=="WV" & year==2004 & qu==1) | (region=="WV" & year==2004 & qu==2) | (region=="WV" & year==2004 & qu==3) | (region=="WV" & year==2004 & qu==4) | (region=="WV" & year==2005 & qu==1) | (region=="WV" & year==2005 & qu==2) | (region=="WV" & year==2005 & qu==3) | (region=="WV" & year==2005 & qu==4) | (region=="WV" & year==2006 & qu==1) | (region=="WV" & year==2006 & qu==2) | (region=="WV" & year==2006 & qu==3) | (region=="WV" & year==2006 & qu==4) | (region=="WV" & year==2007 & qu==1) | (region=="WV" & year==2007 & qu==2) | (region=="WV" & year==2007 & qu==3) | (region=="WV" & year==2007 & qu==4) 
replace isbubbly=1 if  (region=="YO" & year==1999 & qu==4) | (region=="YO" & year==2000 & qu==1) | (region=="YO" & year==2000 & qu==2) | (region=="YO" & year==2000 & qu==3) | (region=="YO" & year==2000 & qu==4) | (region=="YO" & year==2001 & qu==1) | (region=="YO" & year==2001 & qu==2) | (region=="YO" & year==2001 & qu==3) | (region=="YO" & year==2001 & qu==4) | (region=="YO" & year==2002 & qu==1) | (region=="YO" & year==2002 & qu==2) | (region=="YO" & year==2002 & qu==3) | (region=="YO" & year==2002 & qu==4) | (region=="YO" & year==2003 & qu==1) | (region=="YO" & year==2003 & qu==2) | (region=="YO" & year==2003 & qu==3) | (region=="YO" & year==2003 & qu==4) | (region=="YO" & year==2004 & qu==1) | (region=="YO" & year==2004 & qu==2) | (region=="YO" & year==2004 & qu==3) | (region=="YO" & year==2004 & qu==4) | (region=="YO" & year==2005 & qu==1) | (region=="YO" & year==2005 & qu==2) | (region=="YO" & year==2005 & qu==3) | (region=="YO" & year==2006 & qu==1) | (region=="YO" & year==2006 & qu==2) | (region=="YO" & year==2006 & qu==3) 

*************************************************
* Regressions corresponding to Table III
*************************************************

* Table III, Panel A, Column 1
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year > 2001 & year < 2005, absorb(fe_12) cluster(post_0)	   

* Table III, Panel A, Column 3
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & district=="LONDON", absorb(fe_12) cluster(post_0)		   

* Table III, Panel A, Column 4
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & pcl == 1, absorb(fe_12) cluster(post_0)	   

* Table III, Panel A, Column 6
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & ///
			      district=="LONDON" & ((year==1999 & qu==2) | (year==1999 & qu==3) | (year==1999 & qu==4) | (year==2000 & qu==1) | (year==2000 & qu==2) | (year==2000 & qu==3) | (year==2002 & qu==3)  | ///
										(year==2002 & qu==4) | (year==2007 & qu==1) | (year==2007 & qu==2) | (year==2007 & qu==3)), absorb(fe_12) cluster(post_0)

* Table III, Panel A, Column 7
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & ///
			      pcl==1 & ((year==1999 & qu==3) | (year==1999 & qu==4) | (year==2000 & qu==1) | (year==2000 & qu==2) | (year==2000 & qu==3)  | ///
							(year==2007 & qu==1) | (year==2007 & qu==2) | (year==2007 & qu==3)), absorb(fe_12) cluster(post_0)

* Table III, Panel B, Column 1
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & isbubbly==1, absorb(fe_12) cluster(post_0)			   			   

* Table III, Panel B, Column 2 
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & isbubbly==1 & mean_lhs > 0.1, absorb(fe_12) cluster(post_0)			   			   

* Table III, Panel B, Column 3 
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & isbubbly==0, absorb(fe_12) cluster(post_0)			   
 			 
* Table III, Panel B, Column 4
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & isbubbly==0 & mean_lhs > 0.1, absorb(fe_12) cluster(post_0)			
			   
* Table III, Panel B, Column 5
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & dd_pi04==5 & year >= 2004, absorb(fe_12) cluster(post_0)				   				   

* Table III, Panel B, Column 6
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & dd_pig==5 & year >= 2004 & year <= 2007, absorb(fe_12) cluster(post_0)				   

* Table III, Panel B, Column 7
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5  ///
		       if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year > 2000 & dd_tom==1, absorb(fe_12) cluster(post_0)		   

			   
************************************************************************
************************************************************************
* FIGURE II, PANELS C - E
************************************************************************
************************************************************************

***********
* PANEL C
***********

forvalues i=1(1)5 {
	areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///				   
	yg_house2 yg_house3 yg_house4 yg_house5 ///
	if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year>=2004 & dd_pi04==`i', absorb(fe_12) cluster(post_0)			   
	local coef`i'=_b[yg_house5]
	local se`i'=_se[yg_house5]
}

	cap drop coef se max95 min95 bin
	g coef=.
	g se=.
	g bin=.
	replace coef=`coef1' in 1
	replace coef=`coef2' in 2
	replace coef=`coef3' in 3
	replace coef=`coef4' in 4
	replace coef=`coef5' in 5
	replace se=`se1' in 1
	replace se=`se2' in 2
	replace se=`se3' in 3
	replace se=`se4' in 4
	replace se=`se5' in 5
	replace bin=1 in 1
	replace bin=2 in 2
	replace bin=3 in 3
	replace bin=4 in 4
	replace bin=5 in 5
	g max95=coef+se*1.96
	g min95=coef-se*1.96
	
	graph twoway (bar coef bin, barwidth(0.7)) (rcap max95 min95 bin, lcolor(black) lwidth(thick)), ///
			 name(fig_ts_disc, replace) xtitle("Quintile") ///
			 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
			 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 
	graph export "Output\pi04.pdf", replace

***********	
* PANEL D
***********

forvalues i=1(1)5 {
	areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///				   
	yg_house2 yg_house3 yg_house4 yg_house5 ///
	if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year >= 2004 & year <= 2007 & dd_pig==`i'  , absorb(fe_12) cluster(post_0)		   		   
	local coef`i'=_b[yg_house5]
	local se`i'=_se[yg_house5]
}	
	
	cap drop coef se max95 min95 bin
	g coef=.
	g se=.
	g bin=.
	replace coef=`coef1' in 1
	replace coef=`coef2' in 2
	replace coef=`coef3' in 3
	replace coef=`coef4' in 4
	replace coef=`coef5' in 5
	replace se=`se1' in 1
	replace se=`se2' in 2
	replace se=`se3' in 3
	replace se=`se4' in 4
	replace se=`se5' in 5
	replace bin=1 in 1
	replace bin=2 in 2
	replace bin=3 in 3
	replace bin=4 in 4
	replace bin=5 in 5
	g max95=coef+se*1.96
	g min95=coef-se*1.96
	
	graph twoway (bar coef bin, barwidth(0.7)) (rcap max95 min95 bin, lcolor(black) lwidth(thick)), ///
			     name(fig_ts_disc, replace) xtitle("Quintile") ///
			     ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
			     scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 
	graph export "Output\pig.pdf", replace
	
**********************	
* Time on market	
**********************
				   
forvalues i=1(1)5 {
	areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///				   
	yg_house2 yg_house3 yg_house4 yg_house5 ///
	if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99  & year>=2001 & dd_tom==`i', absorb(fe_12) cluster(post_0)		   		   
	local coef`i'=_b[yg_house5]
	local se`i'=_se[yg_house5]
}	

	cap drop coef se max95 min95 bin
	g coef=.
	g se=.
	g bin=.
	replace coef=`coef1' in 1
	replace coef=`coef2' in 2
	replace coef=`coef3' in 3
	replace coef=`coef4' in 4
	replace coef=`coef5' in 5
	replace se=`se1' in 1
	replace se=`se2' in 2
	replace se=`se3' in 3
	replace se=`se4' in 4
	replace se=`se5' in 5
	replace bin=1 in 1
	replace bin=2 in 2
	replace bin=3 in 3
	replace bin=4 in 4
	replace bin=5 in 5
	g max95=coef+se*1.96
	g min95=coef-se*1.96
	
	graph twoway (bar coef bin, barwidth(0.7)) (rcap max95 min95 bin, lcolor(black) lwidth(thick)), ///
			 name(fig_ts_disc, replace) xtitle("Quintile") ///
			 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
			 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 
	graph export "Output\tom".pdf, replace

	
************************************************************************************************
************************************************************************************************
************************************************************************************************
*
* INDIVIDUAL DUMMIES - For Appendix Figure A.17
* - Show if we went through all examples of postcode district - years with enough data to 
*   estimate the size of the bubble, what would the coefficients look like
*
************************************************************************************************
************************************************************************************************
************************************************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

keep if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99
			
gen first_digit  = substr(postcode,1,1)
gen second_digit = substr(postcode,2,1)
destring(second_digit), replace force

cap drop postcode_district     
gen postcode_district     = first_digit if second_digit != .
replace postcode_district = substr(postcode,1,2) if postcode_district == ""

egen level_year = group(postcode_district year)

bysort level_year: egen freehold_share = mean(yg_house1)
bysort level_year: egen long_lh_share  = mean(yg_house5)
bysort level_year: gen  number_trans   = _N

* Now condition on observing enough data to actually run the regression
keep if long_lh_share > 0.1 & freehold_share > 0.1 & number_trans > 1000

**************************************************************
* Do it through loops
**************************************************************

mat def coeff = 0
mat def var   = 0
mat def N     = 0
mat def lhs   = 0
mat def fhs   = 0
mat def area  = 0	

egen prop_type_num = group(prop_type)

levelsof level_year, local(levels)
foreach l of local levels {
	
	areg log_price new_prop i.quarter i.prop_type_num i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
				   yg_house2 yg_house3 yg_house4 yg_house5  if level_year == `l', absorb(post_2) 
	
	mat def new1 = e(b)
	mat def new2 = e(V)

	mat def N      = N \ e(N)
	mat def coeff  = coeff \ (new1[1,"yg_house5"])
	mat def var    = var   \ (new2["yg_house5","yg_house5"])
	
	mat def area = area \ `l'

	sum freehold_share if level_year == `l'
	mat def fhs = fhs \ r(mean)
	
	sum long_lh_share if level_year == `l'
	mat def lhs = lhs \ r(mean)

}

svmat coeff
svmat var
svmat N 
svmat lhs	
svmat fhs
svmat area 

tempfile temp
tempfile temp2

save `temp'

keep coeff1 var1 N1 lhs1 fhs1 area
compress
sort area1

save `temp2'

use `temp', clear

keep level_year postcode_district year
rename level_year area1
duplicates drop

sort  area1
merge area1 using `temp2'
keep  if _merge == 3

gen se    = sqrt(var)
gen tstat = coeff1 / se

hist coeff1 if lhs1 > 0.1, width(0.0025) freq scheme(s1mono) xtitle(Point Estimate)
graph export "Output\PointEstimate.pdf", replace

hist tstat if lhs1 > 0.1, width(0.49) xline(-1.96) xline(1.96) freq scheme(s1mono) xtitle(T-Statistic) start(-3.92) xlabel(-4 -1.96 0 1.96 4 6 8)
graph export "Output\TStat.pdf", replace	
