*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

************************************************************************
* CROSS - SECTION BY IMPORTANCE OF MAINTENANCE FEES
************************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

******************************************
* MERGE IN NUTS CROSS-SECTION
******************************************

sort postcode
cap drop _merge
cap noisily merge postcode using "Cross-Section Data\CrossWalks\postcode_nuts.dta"
keep if _merge == 1 | _merge == 3

cap drop region
gen region = .
replace region = 1 if nuts1 == "North West (England)"    | nuts1 == "North East (England)" | nuts1 == "Yorkshire and The Humber"
replace region = 2 if nuts1 == "South East (England)"    | nuts1 == "London" 
replace region = 3 if nuts1 == "East Midlands (England)" | nuts1 == "East of England" | nuts1 == "West Midlands (England)" | nuts1 == "South West (England)"
tab region 

***************************************************************************************
* FLAT coefficients	
* Table V, Columns 1-3
***************************************************************************************   
	   
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_flat2 yg_flat3 yg_flat4 yg_flat5 yg_flat6 ///
		   	   if prop_type =="F" & clean_ll == 1 & clean1 == 1 & year > 2003, absorb(fe_12) cluster(post_0)
			   
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_flat2 yg_flat3 yg_flat4 yg_flat5 yg_flat6 ///
		   	   if prop_type =="F" & clean_ll == 1 & clean1 == 1 & year > 2003, absorb(fe_12_q) cluster(post_0)

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_flat2 yg_flat3 yg_flat4 yg_flat5 yg_flat6 ///
		   	   if prop_type =="F" & clean_ll == 1 & clean1 == 1 & year > 2003, absorb(fe_12_m) cluster(post_0) 
			   
***************************************************************************************
* HOUSES - Post 2002 Act
* Table V, Column 4
***************************************************************************************   

areg log_price_win new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
				   if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year > 2002, absorb(fe_12)  cluster(post_0)
				
***************************************************************************************
* Coefficients by Region - 2011 and 2012
* Table V, Columns 5-6
***************************************************************************************   

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & region == 1 & (year == 2011 | year == 2012), absorb(fe_12) cluster(post_0)				   

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & region == 3 & (year == 2011 | year == 2012), absorb(fe_12) cluster(post_0)				   
