*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

****************************************************************************************
* Produces results in Table VI, and Figure III
* --> Bubble estimate by the value of redevelopment potential.
****************************************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

********************************************
* READ IN DATA
********************************************

* Merge with housing stock growth
sort  postcode
cap   noisily merge postcode using "Cross-Section Data\HousingStockGrowth.dta"			   
keep  if _merge == 3 | _merge == 1
cap drop _merge

compress

******************************************************************
* Share of flats
******************************************************************

* By LSOA
cap drop share_flat
bysort lsoa: egen share_flat = mean(is_flat)

cap drop dd_sf
xtile dd_sf=share_flat if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, n(5) 

* By LSOA and year
cap drop share_flat2
bysort lsoa year: egen share_flat2 = mean(is_flat)

cap drop dd_sf2
xtile    dd_sf2 = share_flat2 if share_flat2>0 & prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, n(4) 
replace  dd_sf2 = dd_sf2+1
replace  dd_sf2 = 1 if share_flat2==0 & prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99

***************************************************************************************
* Share flats in LSOA (Table VI, Column 5 and Figure III, Panel E)
***************************************************************************************

areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_sf yg_house3##i.dd_sf yg_house4##i.dd_sf yg_house5##i.dd_sf ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 , absorb(fe_12) cluster(post_0)

local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_sf]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_sf]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_sf]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_sf]
local coeft5=r(estimate)
local set5=r(se)
	
cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5
		
cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96


graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 

***************************************************************************************	
* Share flats by LSOA and year (Table VI, Column 6 and Figure III, Panel F)	
***************************************************************************************
	
areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_sf2 yg_house3##i.dd_sf2 yg_house4##i.dd_sf2 yg_house5##i.dd_sf2 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 , absorb(fe_12) cluster(post_0)

local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_sf2]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_sf2]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_sf2]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_sf2]
local coeft5=r(estimate)
local set5=r(se)
	
cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5

cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96


graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 

******************************************************************
* New Properties
******************************************************************

* By LSOA
cap drop new_average
bysort lsoa: egen new_average = mean(new_prop)

cap drop dd_new
xtile dd_new=new_average if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, n(5) 

* By LSOA and year
cap drop new_average2
bysort lsoa year: egen new_average2 = mean(new_prop)

cap drop dd_new2
xtile dd_new2=new_average2 if new_average2>0 & prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, n(4) 
replace dd_new2=dd_new2+1
replace dd_new2=1 if new_average2==0 & prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99
	
*******************************************************************************
* Share new flats by LSOA and year (Table 6, Column 3 and Figure 3, Panel C)		
*******************************************************************************
	
areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_new yg_house3##i.dd_new yg_house4##i.dd_new yg_house5##i.dd_new ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 , absorb(fe_12) cluster(post_0)
	
local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_new]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_new]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_new]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_new]
local coeft5=r(estimate)
local set5=r(se)

cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5
	
cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96

graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 

*********************************************************************************	
* Share new flats by LSOA and year (Table 6, Column 4 and Figure 3, Panel D)		
*********************************************************************************
	
areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_new2 yg_house3##i.dd_new2 yg_house4##i.dd_new2 yg_house5##i.dd_new2 ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 , absorb(fe_12) cluster(post_0)

local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_new2]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_new2]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_new2]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_new2]
local coeft5=r(estimate)
local set5=r(se)

cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5
	
cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96
	
graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 

		 
******************************************************************
******************************************************************
* By Change in Housing Stock
******************************************************************
******************************************************************

* Full sample (Table 6, Column 1 and Figure 3, Panel A)		

cap drop dd_change
xtile dd_change=change, n(5)
	
areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_change yg_house3##i.dd_change yg_house4##i.dd_change yg_house5##i.dd_change ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 , absorb(fe_12) cluster(post_0)
	
local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_change]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_change]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_change]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_change]
local coeft5=r(estimate)
local set5=r(se)

cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5

cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96
	
graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 

******************************************************************
* Only 2001-2011 (Table 6, Column 2 and Figure 3, Panel B)		
******************************************************************

areg log_price i.new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
               yg_house2##i.dd_change yg_house3##i.dd_change yg_house4##i.dd_change yg_house5##i.dd_change ///
			   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 & year > 2000 & year < 2012, absorb(fe_12) cluster(post_0)

local coeft1=_b[1.yg_house5]
local set1=_se[1.yg_house5]
lincom _b[1.yg_house5] + _b[1.yg_house5#2.dd_change]
local coeft2=r(estimate)
local set2=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#3.dd_change]
local coeft3=r(estimate)
local set3=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#4.dd_change]
local coeft4=r(estimate)
local set4=r(se)
lincom _b[1.yg_house5] + _b[1.yg_house5#5.dd_change]
local coeft5=r(estimate)
local set5=r(se)

cap drop bin
g bin=.
replace bin=1 in 1
replace bin=2 in 2
replace bin=3 in 3
replace bin=4 in 4
replace bin=5 in 5

cap drop coeft set maxt95 mint95
g coeft=.
g set=.

replace coeft=`coeft1' in 1
replace coeft=`coeft2' in 2
replace coeft=`coeft3' in 3
replace coeft=`coeft4' in 4
replace coeft=`coeft5' in 5
replace set=`set1' in 1
replace set=`set2' in 2
replace set=`set3' in 3
replace set=`set4' in 4
replace set=`set5' in 5
g maxt95=coeft+set*1.96
g mint95=coeft-set*1.96

graph twoway (bar coeft bin, barwidth(0.7)) (rcap maxt95 mint95 bin, lcolor(black) lwidth(thick)), ///
		 name(fig_ts_disc, replace) xtitle("Quintile") ///
		 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
		 scheme(s1mono) legend(off)  yscale(range(-0.05 0.05)) ylabel(#7) xlabel(#5) 
