*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

*********************************************************************************************
* This file produces the regression analysis for Table IV, Column 3
* --> Regression analysis
* --> This rent data is for houses (the Rightmove-provided rent data in Step 4 is flats only)
*********************************************************************************************

************************
* RIGHTMOVE
************************

import excel "New Rent Data\rightmove_houses_1.xls", sheet("rightmove_houses") firstrow clear

tempfile temp
save `temp'

import excel "New Rent Data\rightmove_houses_2.xls", sheet("rightmove_houses") firstrow clear

append using `temp'

save "Data\Rightmove_Rent_Data.dta", replace

***********
* ZOOPLA 
***********

import excel "New Rent Data\zoopla_houses.xls", sheet("zoopla_houses") firstrow clear	

destring rent_pcm, replace force

append using "New Rent Data\Rightmove_Rent_Data.dta"

keep if accuracy == "ROOFTOP"

drop if postcode == ""
duplicates drop

* Controls
gen log_rent = log(rent_pcm)

save "Data\Rent_Data.dta", replace

************************************************************************
* Do Parts from Transaction Data
* - Determine which full postcodes only have a single transaction type
************************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

drop if prop_type == "F"

gen min 	 = years_group_new_house
gen max 	 = years_group_new_house
gen mean_lh  = years_group_new_house

gen n = 1

replace bedrooms  = . if bedrooms  == 99
replace bathrooms = . if bathrooms == 99

gen bed_mean = bedrooms
gen bath_mean = bathrooms
	
collapse (count) n (min) min (max) max (mean) age floor_area bed_mean bath_mean mean_lh, by(postcode)

gen same = (min == max)
keep if same == 1      // Only keep postcodes with a single transaction type.

sort postcode
tempfile temp
save `temp'

*********************************
* Now create dataset that works
*********************************
 
use "Data\Rent_Data.dta"

sort postcode 
merge postcode using `temp'
keep if _merge == 3

** CONTROLS
cap drop age_group
egen     age_group = cut(age), group(10) 
replace  age_group = 99 if age_group == .

cap drop floor_group
egen     floor_group = cut(floor_area), group(10)
replace  floor_group = 99 if floor_group == .

replace bath_mean = round(bath_mean)
replace bath_mean = 99 if bath_mean == .
replace bath_mean = 6  if bath_mean > 6 & bath_mean != 99

replace bed_mean = round(bed_mean)
replace bed_mean = 99 if bath_mean == .
replace bed_mean = 8  if bath_mean > 8 & bath_mean != 99

replace bedrooms  = 99 if bedrooms == . 
replace bathrooms = 99 if bathrooms == . 

* Postcode Fixed Effects
gen pos_empty  = strpos(postcode," ")
gen post_0     = substr(postcode,1,pos_empty)
replace post_0 = trim(post_0)

* Leasehold characteristic
replace mean_lh = round(mean_lh)

gen furnished = (furnishing == "Furnished")
gen pp        = (rent_is_pp == "Y")

gen bed_pos = strpos(property_title,"bedroom")
gen type    = substr(property_title,bed_pos + 8,.)

egen type_bin = group(type)
egen fe       = group(post_0 type_bin)

* Now regressions for Table IV, Column 3
areg log_rent i.bedrooms i.bathrooms i.furnished                           i.pp i.mean_lh, absorb(fe) cluster(post_0)

* Use average characteristics within each zip code insteaed (a robustness check reported in Appendix A.1.3
areg log_rent i.bed_mean i.bath_mean i.furnished i.floor_group i.age_group i.pp i.mean_lh, absorb(fe) cluster(post_0)
