*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

******************************************************************************************************
* This file reads in proprietary data provided by Rightmove on property characteristics and listing dates
* - These data were delivered in 3 batches
******************************************************************************************************

clear
set more off

import delimited "Data\BATCH2_5-10m_Processed.txt", clear 

rename address_1 flat_number 
rename address_2 street_number 
rename address_3 street 
rename address_4 district
rename address_5 town
rename address_6 county

tempfile temp1
save `temp1'

import delimited "Data\BATCH2_5m_Processed.txt", clear 

rename address_1 flat_number 
rename address_2 street_number 
rename address_3 street 
rename address_4 district
rename address_5 town
rename address_6 county

tempfile temp
save `temp'

import delimited "Data\BATCH1_Processed.txt", clear 
append using `temp'
append using `temp1'

* Drop properties that RM could not match
drop   if latitude_100m == .         

* Now drop duplicate obeservations in the RM data
duplicates drop street_number flat_number street town county postcode prop_type prop_style beds_rightmove living bath cloaks conservatory unexp_term built condition tenure floor_area, force

* Create indicator variables for different values of property characteristics
egen condition_ind  = group(condition), mi
egen heating_ind    = group(central_heating), mi
egen parking_ind    = group(parking), mi
egen property_style = group(prop_style), mi

* Some variables we'll also see in Zoopla Scrape Data
rename tenure     tenure_rightmove
rename prop_type  prop_type_rightmove
rename beds       beds_rightmove
rename prop_style prop_style_rightmove

* Now extract data of listing start (Will be used for Time on Market)
gen     y_pos         = substr(listing_start,8,1)
replace listing_start = substr(listing_start,1,7) + "20" + substr(listing_start,8,.) if y_pos == "0" | y_pos == "1"
replace listing_start = proper(listing_start)
gen     list_start_dt = date(listing_start,"DMY")
format  list_start_dt  %td

* Format address variables
replace flat_number = subinstr(flat_number,"FLAT","",.)
replace flat_number = subinstr(flat_number,"APARTMENT","",.)
replace flat_number = trim(flat_number)

* Drop some variables we won't need any more
drop condition central_heating parking y_pos listing_start town county
drop address_7 user_reference unexp_term locality district             

duplicates drop

* For various listings of the same property, if we have characteristics in a later listing, attach that to all earlier listings
foreach var in "beds_rightmove" "living" "bath" "cloaks" "conservatory" "floor_area" "built" "list_start_dt" "list_end_dt" {
	bysort street_number flat_number street postcode (`var'): replace `var' = `var'[1]
}

compress

save "Data\RightmoveData.dta", replace
