*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

************************************************************************
* This file merges the different datasets together
************************************************************************

clear 
set more off
set matsize 11000

************************************************************************
* COMPILE DATASET
************************************************************************

use "Data\TransactionsLRLong.dta", clear

drop locality
drop if duration == "U"
drop if duration == ""
drop if postcode == ""

* Merge in the Rightmove Property Characteristics Data
sort  street_number flat_number street postcode
merge street_number flat_number street postcode using "Data\RightmoveData.dta"
drop  if _merge == 2
cap   drop _merge

* Merge in the Zoopla Property Characteristics Data
sort  postcode street_number flat_number street town 
merge postcode street_number flat_number street town using "Data\ZooplaScrape.dta"
drop  if _merge == 2
cap   drop _merge

**************************************************************************************************************
* Produce merge of Zoopla and Rightmove Data
*    If both are available, we take the property characteristics from Rightmove, but we add additional 
* 	 information from the Zoopla Data Scrape. When both are available, a quick test shows more than 95% 
*    match between the two data sources.
**************************************************************************************************************

gen bedrooms     = beds_rightmove
replace bedrooms = beds if bedrooms == . | bedrooms == 0
drop beds beds_rightmove

gen bathrooms      = bath
replace bathrooms  = baths if bathrooms == . | bathrooms == 0
drop bath baths

* Generate a "missing" characteristic as "99" for mismeasured and missing rooms.
replace bedrooms     = 99 if bedrooms     == . | bedrooms > 8
replace bathrooms    = 99 if bathrooms    == . | bathrooms > 8
replace living       = 99 if living       == . | living > 8
replace conservatory = 99 if conservatory == . | conservatory > 8

foreach var in property_style built condition_ind heating_ind parking_ind {
	replace `var' = 99 if `var' == .
}

compress

********************************************************************
* Now do some data cleaning, then merge information on the lease 
* length via the "unique_id" variable used by the Land Registry
********************************************************************

replace unique_id = subinstr(unique_id,"{","",.)
replace unique_id = subinstr(unique_id,"}","",.)
sort unique_id

merge unique_id using "Data\LeaseLengthLR.dta"
drop if _merge == 2
drop _merge unique_id

******************************************
* Save Merged Dataset 
******************************************

drop town county tenure_rightmove latitude_100m latitude_100m longitude_100m

duplicates drop
compress

save "Data\MergedDataRaw.dta", replace
