*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

***********************************************************************
* Produces Summary Statistics in Table I of the Paper
***********************************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

* Generate a variable that corresponds to the sample we have in the regressions. For summary statistics we only present
*   information on freeholds and extremely-long leaseholds.
gen issample=1 if prop_type !="F"  & (yg_house5 ==1 | leasehold == 0) & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99 

* Bedrooms
sum  bedrooms if issample==1 & yg_house5==1 & bedrooms != 99,d
sum  bedrooms if issample==1 & yg_house5==0 & bedrooms != 99,d
reg  bedrooms yg_house5 if issample==1 & bedrooms != 99, cluster(post_0)
areg bedrooms yg_house5 if issample==1 & bedrooms != 99, cluster(post_0) absorb(fe_12)

* Bathrooms
sum  bathrooms if issample==1 & yg_house5==1 & bathrooms!=99,d
sum  bathrooms if issample==1 & yg_house5==0  & bathrooms!=99,d
reg  bathrooms yg_house5 if issample==1 & bathrooms!=99, cluster(post_0)
areg bathrooms yg_house5 if issample==1 & bathrooms!=99, cluster(post_0) absorb(fe_12)

* Property Size
sum  floor_area if issample==1 & yg_house5==1, d
sum  floor_area if issample==1 & yg_house5==0, d
reg  floor_area yg_house5 if issample==1, cluster(post_0)
areg floor_area yg_house5 if issample==1, cluster(post_0) absorb(fe_12)

* Property Age
sum  age if issample==1 & yg_house5==1 & age>=0, d
sum  age if issample==1 & yg_house5==0 & age>=0, d
reg  age yg_house5 if issample==1 & age>=0, cluster(post_0)
areg age yg_house5 if issample==1 & age>=0, cluster(post_0) absorb(fe_12)

* PRICE	
sum  log_price if issample==1 & yg_house5==1,d
sum  log_price if issample==1 & yg_house5==0,d
reg  log_price yg_house5 if issample==1, cluster(post_0)
areg log_price yg_house5 if issample==1, cluster(post_0) absorb(fe_12)

* Number of Observations
count if issample==1 & yg_house5==0
count if issample==1 & yg_house5==1

********************************************************************************
* Prepare Data for Map that shows share of each type of contract per geography
* - This will go into Appendix Figure
********************************************************************************

* Keep list of all postcodes
save tempsumm.dta

keep post_0
duplicates drop
save postlist.dta, replace

use tempsumm.dta, clear

gen     lh=0 if issample==1 & yg_house5==0
replace lh=1 if issample==1 & yg_house5==1

keep post_0 lh
keep if lh!=.

collapse (mean) mean_lh=lh (sum) sum_lh=lh (count) count_lh=lh, by(post_0)

export delimited using "Output\bubbles_mapdata.csv", replace
