*******************************************************************************************
*******************************************************************************************
* - "No-Bubble Condition: Model-Free Tests in Housing Markets"
*   Giglio, Maggiori, and Stroebel
*   Econometrica
*******************************************************************************************
*******************************************************************************************

*********************************************************
* File runs some of the baseline Regressions
*********************************************************

clear 
set more off
set matsize 11000

use "Data\bubble.dta", clear

***************************************************
* HOUSES
* TABLE II, Columns 1-4
***************************************************

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12) cluster(post_0)
eststo col1

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12_q) cluster(post_0)
eststo col2

areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
			   if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12_m)  cluster(post_0)
eststo col3

areg log_price_win new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
				   if prop_type !="F" & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12)  cluster(post_0)
eststo col4

esttab col1 col2 col3 col4 using "Output\Bubble_UK_Main.tex", ///
	   replace width(\hsize) nocon b(3) se(3) title(Impact of Lease Type on Price Level - Flats) sty(tex) stats(r2_a ymean N, labels(R-squared MeanDepVar N)) ///
	   noconstant star(* 0.10 ** 0.05 *** 0.01) label ///
	   keep(yg_house5)   

***************************************************************************************
* UK Time-On-Market
* Table IV, Columns 4-5
***************************************************************************************   
		   
areg log_tom new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12) cluster(post_0)

areg log_tom new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind yg_house2 yg_house3 yg_house4 yg_house5 ///
		   	   if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12_m) cluster(post_0)

	   
***************************************************************************************
* Year-by-year coefficients	- UK
* - Figure II, Panel A
***************************************************************************************
	  
forval i = 1995(1)2013 {
	  gen lh_999y_`i' = 0
	  replace lh_999y_`i' = 1 if yg_house5 == 1 & year == `i'
}
		  
areg log_price new_prop i.bedrooms i.bathrooms i.floor_group i.property_style i.age_group i.condition_ind i.heating_ind i.parking_ind ///
              yg_house2 yg_house3 yg_house4 lh_999y_* ///
		   	  if prop_type !="F"  & clean_ll == 1 & clean1 == 1 & bedrooms != 99 & age_group != 99, absorb(fe_12) cluster(post_0)
			  
preserve

parmest, norestore

keep if strpos(parm,"lh_") != 0
gen ll_year = substr(parm,9,4)
destring(ll_year), replace force

graph twoway (bar estimate ll_year, barwidth(0.7)) (rcap max95 min95 ll_year, lcolor(black) lwidth(thick)), ///
			 name(fig_ts_disc, replace) xtitle("Year") ///
			 ytitle("Discount of 700+ Year Leasehold to Freehold") title("Leasehold Discounts") ///
			 scheme(s1mono) legend(off)  yscale(range(-0.03 0.03)) ylabel(#7) xlabel(#18, angle(vertical)) 

			 graph export "Output\Bubble_UK.pdf", replace
		 
restore			   			  

************************************************************
* RESIDUAL GRAPHS
************************************************************
	   			   
areg log_price if bedrooms>0 & bedrooms < 8 & prop_type != "F" & clean_ll == 1 & clean1 == 1, absorb(fe_12)
predict resid_price_house, r

twoway  (kdensity resid_price_house  if resid_price_house > -2 & resid_price_house < 2 & yg_house5 == 1, bwidth(0.4) lpattern(dash))  ///
		(kdensity resid_price_house  if resid_price_house > -2 & resid_price_house < 2 & leasehold == 0, bwidth(0.4) lpattern(longdash)),  ///				   
		legend(on order(1 "999-Year Leasehold" 2 "Freehold") cols(2) region(lstyle(none))) scheme(s1mono) xtitle("Log(Price) - Residual") ytitle("") scale(1.4)

graph export "Output\uk_price_resid_house_bubble.pdf", replace	  


areg bedrooms if bedrooms>0 & bedrooms < 8 & prop_type != "F" & clean_ll == 1 & clean1 == 1, absorb(fe_12)
predict resid_beds_house, r

twoway  (kdensity resid_beds_house  if resid_beds_house > -5 & resid_beds_house < 5 & yg_house5 == 1, bwidth(0.4) lpattern(dash))  ///
		(kdensity resid_beds_house  if resid_beds_house > -5 & resid_beds_house < 5 & leasehold == 0, bwidth(0.4) lpattern(longdash)),  ///				   
		legend(on order(1 "999-Year Leasehold" 2 "Freehold") cols(2) region(lstyle(none))) scheme(s1mono) xtitle("Bedrooms - Residual") ytitle("") scale(1.4)
	   
graph export "Output\uk_beds_resid_house_bubble.pdf", replace	  

areg bathrooms if bathrooms> 0 & bathrooms < 8 & prop_type != "F" & clean_ll == 1 & clean1 == 1, absorb(fe_12)
predict resid_baths_house, r

twoway  (kdensity resid_baths_house  if resid_baths_house > -2 & resid_baths_house < 2 & yg_house5 == 1, bwidth(0.4) lpattern(dash))  ///
		(kdensity resid_baths_house  if resid_baths_house > -2 & resid_baths_house < 2 & leasehold == 0, bwidth(0.4) lpattern(longdash)),  ///				   
		legend(on order(1 "999-Year Leasehold" 2 "Freehold") cols(2) region(lstyle(none))) scheme(s1mono) xtitle("Bathrooms - Residual") ytitle("") scale(1.4)	  

graph export "Output\uk_baths_resid_house_bubble.pdf", replace 

		
areg floor_area if floor_area>=0 & floor_area < 400 & prop_type != "F" & clean_ll == 1 & clean1 == 1, absorb(fe_12)
predict resid_size_house, r

twoway  (kdensity resid_size_house  if resid_size_house > -100 & resid_size_house < 100 & yg_house5 == 1, bwidth(10) lpattern(dash))  ///
		(kdensity resid_size_house  if resid_size_house > -100 & resid_size_house < 100 & leasehold == 0, bwidth(10) lpattern(longdash)),  ///				   
		legend(on order(1 "999-Year Leasehold" 2 "Freehold") cols(2) region(lstyle(none))) scheme(s1mono) xtitle("House Size - Residual") ytitle("") scale(1.4)	  

graph export "Output\uk_size_resid_house_bubble.pdf", replace 


areg age if age>=0 & age!=. & prop_type != "F" & clean_ll == 1 & clean1 == 1, absorb(fe_12)
predict resid_age_house, r

twoway  (kdensity resid_age_house  if resid_age_house > -100 & resid_age_house < 100 & yg_house5 == 1, bwidth(10) lpattern(dash))  ///
		(kdensity resid_age_house  if resid_age_house > -100 & resid_age_house < 100 & leasehold == 0, bwidth(10) lpattern(longdash)),  ///				   
		legend(on order(1 "999-Year Leasehold" 2 "Freehold") cols(2) region(lstyle(none))) scheme(s1mono) xtitle("House Age - Residual") ytitle("") scale(1.4)	  

graph export "Output\uk_age_resid_house_bubble.pdf", replace 


